(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    121583,       3250]*)
(*NotebookOutlinePosition[    122668,       3289]*)
(*  CellTagsIndexPosition[    122572,       3282]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Level control-2
PI controller\
\>", "Title",
  TextAlignment->Center],

Cell["\<\
B\[EAcute]la Pal\[AAcute]ncz
Budapest Technical University,Hungary
palancz@epito.bme.hu
Budapest,2003\
\>", "Author",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "If we should like to eliminate the deviation between of the new steady \
state level and old one, an integrating term  should be employed in our \
controller. Now, starting with the transfer function form of the linearized \
model, we design a ",
  StyleBox["PI controller",
    FontWeight->"Bold"],
  " for the water storage level control",
  StyleBox[" in symbolic form",
    FontSlant->"Italic"],
  ". The simulations of the linear and nonlinear closed loop are presented."
}], "Text"],

Cell[BoxData[
    \(<< ControlSystems`\)], "Input",
  CellTags->"1.1"],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Connecting process and controller models", "Section"],

Cell["\<\
Let us start with the transfer function of the linearized model:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControlObjectTF = 
      TransferFunction[
        s, {\(2\ \@h0\)\/\(c0 + 2\ A\ \@h0\ s\), \(-\(\(2\ h0\)\/\(c0 + 
                  2\ A\ \@h0\ s\)\)\)}]\)], "Input"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(2\ \@h0\)\/\(c0 + 2\ A\ \@h0\ s\), \(-\(\(2\ h0\)\/\(c0 + 
                  2\ A\ \@h0\ s\)\)\)}}]\)], "Output"]
}, Open  ]],

Cell["The transfer function of the PI controller is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi = TransferFunction[s, k\_p + k\_i\/s]\)], "Input",
  CellTags->"6.5"],

Cell[BoxData[
    \(TransferFunction[s, {{k\_i\/s + k\_p}}]\)], "Output"]
}, Open  ]],

Cell["\<\
Now, we should connect  these two units in the following way:\
\>", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@00024X0@0005P0000200000P000982001Y0@00
00000000001/A000Q2D00215CDH00040:24001L100030000000000000000000080<005P2003C0000
WP0000X0000@0000MP0009X000090000400009H2001[0@00600000`0000000026@0000`0003oool2
600000`0003oool25P0000`0000H00004P0000`0000100006`0001000000000000000580001<0@00
0@000>3oool0000000000000002@0@000000kP00019D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000;no_kno_kno_kno_kno_kno_kno_kno_kno_kno_`00002o_kno_kno_kno_kno_kno_kno_kno
_kno_kno_kno_kno_kno_kno_kno_kno_kno_kl0002o_kno_koooooooooooooooooooooooooooooo
`<30`<30`<30`<30`<30`<30`<30P820_kno_kno_knooooo_kno_knoool00<30`<30`<30`<30`<30
`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820_knooooo`<30`<300000000000000000
00000000000000000@410@410@410L309@0000`000010000E00007P0000l0@00L@0009d1002D0000
0@000000dd400==1/P4000/100070000C0000000000000000000000000000000G0000500LP1_06<0
I@1c07<0oolB00002`000100000>00003P0000`0000=00005P0000`0000000004P0000`000020000
9@0000`000000020C@0006`0003m00008@000=d1002Y0000L`400;/0003Q0000R@000240l0000000
00000000P3l0000000000000P3l00000000000000000000000000000000000000000000000000000
9P0001`000020000000000400001000000000RD0000<00000P0002D0000<00000000P2/0000H0000
L0400;P0001@0P00@04002D0000<00001`00P2P0000<00000P0001P0000<000000000QH0000<0000
60000180000<00000@0001/0000@000000000000000U000030000000081D0000N00003T1001^0000
VP40094000010000003C@@00dd6_0@00204000L0001<0000000000000000000000000000001L0000
D01b06l0H`1U07<0L`3ooa80000;0000400000h0000>0000300000d0000F000030000000000B0000
30000080000H000030000?ooo`8F0000300001P0000B000030000040000K00004000000000000000
E00008P0000[0@00<@400:h1001D0@000@000000dd400==1X@400</1000:0000C000000000000000
0000000000000000H00004<0K`1^07@0LP1_06`0K01U07805@000100000@00002@0000/0000@0000
2@0000T0000>00002P0001H0000<000000000180000<00000P0002D0000<00000000P4d0001/0000
o@000>40003M0@00J@4007<1001k0@00h@0008T0000Q0?00000000000000080o000000000000080o
000000000000000000000000000000000000000000000000000002H0000L00000P00000000010000
0@000000008U000030000080000U000030000000080[000060000701001h0@00D0800002000U0000
300000L0080X000030000080000H000030000000008F0000300001P0000B000030000040000K0000
40000000000000009@0000`000000020E00008P0000X0@00;P400:/1001A0@000@000000dd400==1
WP400<P1000:0000C0000000000000000000000000000000H00004<0K`1^07@0LP1_06`0K01U0780
5@000100000@00002@0000/0000@00002@0000T0000>00002P0001H0000<000000000180000<0000
0P0002D0000<00001`00P4H0000X0000700004M4BD<20000_P000<l0001c0@00h`000000000k0000
200001/0000@0000`0000=P0000V000070000080000000000`0000<0000000009@0000`000020000
9@0000`000050020=P000100001S0@00f00003`000080000@00001P00000000000000?oooooooooo
9@0000`000080020:00000`0000200009@0000`0000800209@0000`000040020EP0002P0003[0000
=`000?X0001600000`000641h01`0MP0H@7A02D0000<00001`00P2D0000<00000000P4H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002n00009`4007<1000k0@00000003/000080000
6`00010000300000<04002H0000L00000P000000000300000`000000000U000030000080000U0000
300000D0080f0000400006<1000`0@00?00000P0001000006000000000000000oooooooooolU0000
300000P0080X000030000080000U0000300000P0080U0000300000@0081F0000:0000>/0002?0000
nP0009h000030000H@4h0G01<05Q0BT19@0000`0000700209@0000`000000020AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0004h2003_00002`<000<100000000>`0000P0000K0000
40000502003h00009P0001`000020000000000<000030000000002D0000<00000P0002D0000<0000
1@00P3H0000@0000n`800?P0000l000020000400000H000000000000003oooooooooobD0000<0000
2000P2P0000<00000P0002D0000<00002000P2D0000<00001000P5H0000X0000P`8005L0002B0P00
IP0000<0003i0P0120?h0?T2l@0U0000300000L0080U00003000000008160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000YP800?H0002[0P00``400000000k0000200001/0000@0000
Z0800?P0000V000070000080000000000`0000<0000000009@0000`0000200009@0000`000050020
=P000100002X0P00`04003`000080000@00001P00000000000000?oooooooooo9@0000`000070020
:00000`0000200009@0000`0000700209@0000`000000020AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P0004h2002f0@00Z`800<T100000000>`0000P0000K000040000:P200300@00
9P0001`000020000000000<000030000000002D0000<00000P0002D0000<00001@00P3H0000@0000
G@800<01000l000020000400000H000000000000003oooooooooobD0000<00002000P2P0000<0000
0P0002D0000<00002000P2D0000<00001000P5H0000X0000fP4001h1003Y0@00;@4000<0001O0[P1
D0;00El2a`4U0000300000L0080U00003000000008160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000;P400<H1001c0@00b`400000000k0000200001/0000@0000L0400<P1000V0000
70000080000000000`0000<0000000009@0000`0000200009@0000`000050020=P000100000`0@00
b04003`000080000@00001P00000000000000?oooooooooo9@0000`000070020:00000`000020000
9@0000`0000700209@0000`000000020AP0001@000080000AdA9@`<000160000:00001`00017A4U3
0P0002L1000^0@00>P400</100000000>`0000P0000K00004000030100380@009P0001`000020000
000000<000030000000002D0000<00000P0002D0000<00001@00P3H0000@0000<04003d1000l0000
20000400000H000000000000003oooooooooobD0000<00002000P2P0000<00000P0002D0000<0000
2000P2D0000<00001000P5H0000X0000/`0009H000320000Y@0000<0000h0Cl1<04`0BT1?`4U0000
300000L0080U00003000000008160000500000P00017A4U30`0002D0000<00002000P2D0000<0000
1@00P2/0000H0000gP0009`0000D0@00c00001H0000<000060000180000<00000@0001/0000@0000
00000000000U000030000000081D0000E0000780000V0000R00004T000010000003C@@00dd7X0000
`0000040001<0000000000000000000000000000001@0000E@30`1L0000F000030000000000B0000
30000080001B0000C0400080003[oooo0000000000000000T04000000>h0000BE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h0002ooooo_kno_knooooo`<30`<30`<30`<30`<30`<000000`<30`<30
`<30`<30`<30`<30`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30`<300000`<30`<30`<30
`<30`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30
0030P820_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820oooo`<30
`<30`000000000000000000000000000000000410@410@410@70`2D0000<00000P0002P0000<0000
0@0001H0000<000060000180000<00000@0001/0000@000000000000000U000030000080001D0000
E00008T0000^0000T`0004@000010000003C@@00dd7o0000b0000040001<00000000000000000000
00000000001@0000<@30`0/0000F000030000000000B000030000080000U0000300000P0080U0000
300000D0080[000060000=h0003/0000504001`1001B0000C0400040003Poooo0000000000000000
T04000000>h0000BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00030`<30`<30`<30`<30`<30
`<30P820_knooooo`<000000`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820oooo`<30
`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820_kno_kno_knooooo
_kno_knooooo`<30`<30`<30`<30`<300030`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820
_knooooo`<30`<30`<30`<30`<30`<30`<30`000000000000000000000000000000000410@410@41
0@70`2D0000<00000@0002P0000<00000P0001H0000<000060000180000<00000@0001/0000@0000
00000000000U000030000000080U000030000040001D0000E0000780001f0000R00009T000010000
003C@@00dd7X000040400040001<0000000000000000000000000000001@0000E@30`1L0000F0000
30000000000B000030000080001B0000C0400080003[oooo0000000000000000T04000000>h0000B
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003o`<30`<30`<30`<30`<30`<30`<30`<30`<30
`<000000`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30
`<30P820oooo`<30`<30`<30`<30`<30`<30`<30000000000000`<30`<30`<30`<30`<30`<30P820
_kno_kno_knooooo002o_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30
`<30`<30`<30P820_knoo`00000000000000000000000000000000410@410@410@70`2D0000<0000
0P0002P0000<00000@0001H0000<000060000180000<00000@0001/0000@000000000000000U0000
30000080001D0000E00008T0001n0000T`0009@000010000003C@@00dd7o000060400040001<0000
000000000000000000000000001@0000<P30`0/0000F000030000000000B000030000080000U0000
300000P0080U0000300000D0080[000060000:h2002l0000f@800>`0001B0000C0400040003Poooo
0000000000000000T04000000>h0000BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00030`<30
`<30`<30`<30`<30`<30`<30`<30`<30`<000000_knooooo`<30`<30`<30`<30`<30`<30`<30`<30
`<30`<30`<30`<30`<30P820oooo`<30`<30`<30`<30`<30`<30`<30000000000000`<30`<30`<30
`<30`<30`<30P820_kno_kno_knooooo_kno_knooooo`<300030`<30`<30`<300000000000000000
000000000000`<30`<30`<30`<30P820_knooooo`<30`<30`<30`000000000000000000000000000
000000410@410@410@60_bD0000<00000@0002P0000<00000P0001H0000<000060000180000<0000
0@0001/0000@000000000000000U000030000000080U000030000040001D0000E000048200160000
F08006T000010000003C@@00dd6h0P00h0000040001<0000000000000000000000000000001@0000
F@2o_aL0000F000030000000000B000030000080000U0000300000P0080U0000300000D0080[0000
600007P0001`0@008`400:01000F0000300001P0000B000030000040000K00004000000000000000
9@0000`000000020E0000600000<0000nP000300000M0@000@000000dd400==1PP0009@100030000
C0000000000000000000000000000000E00002d0:01[0<302`0000X0000@00005P0000`000000000
4P0000`000020000DP0004`100020000joooo`0000000000000009010000003^00004U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000`<30`<30`<30P820_knooooo`<30`<30`<30000000000000
000000000000`<30`<30`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30`<300000`<300000
`<30`<30`<30`<30`<30P820_knooooo`<30`<300000`<30`<300000`<30`<300000`<30`<30`<30
`<30P000oooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820
_kno_kno_kl0000000000000000000000000000000010@410@410@41`<0U000030000080000X0000
30000040000F0000300001P0000B000030000040000K000040000000000000009@0000`000020000
E00005@0000a00000P4003/0000H0@000@000000dd400==1Y`0009`100010000C000000000000000
0000000000000000D0000700`<0;00005P0000`0000000004P0000`000020000DP0004`100010000
h?ooo`0000000000000009010000003^00004U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
`<30`<30`<30`<300000`<30`<30`<300000`<3000000<30`<30`<30`<30P820_knooooo`<30`<30
`<300000`<300000`<30`<30`<30`<30`<30`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30
`<300000`<300000`<30`<30`<30`<30`<30P820_knooooo`<30`000`<3000000000`<3000000000
`<30`<30`<30`<30`<30P820oooo`<30`<30`<30`<30`<30`<30`<30`<0000000000000000000000
0000000000010@410@410@41_klU000030000040000X000030000080000F0000300001P0000B0000
30000040000K000040000000000000009@0000`000010000E00005P0000l0000nP0005d0000M0@00
0@000000dd400==1/P0009@100020000C0000000000000000000000000000000D00002/0J`0B0000
400001H0000<000000000180000<00000P000580001<0@000P000>_oool0000000000000002@0@00
0000kP00019D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000<30`<30P820_kno_kno_knooooo
_kno_knooooo`0000030`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820
_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820_knooooo`<30
`<30`<30`<30`<30`<30`<30`<000<30`<30`<30`<30`<30`<30P820_knooooo`<30`<30`<30`<30
`<30`<30`<30`<30`<30`<30`<30`<30000000000000000000000000000000000@410@410@410L30
9@0000`000020000:00000`0000100005P0000`0000H00004P0000`0000100006`00010000000000
000002D0000<00000P0005@0001D0000GP000081001S00006040004000000==1003C@M@0002L0@00
0@0004`000000000000000000000000000000500001Y0<301P0001H0000<000000000180000<0000
0P000580001<0@000@000>3oool0000000000000002@0@000000kP00019D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP000<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`0000030`<30`<30P820
_kno_kno_knooooo_kno_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30
`<30`<30`<30P820_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<000<30
P820_knooooo`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30`<30P820_knooooo
000000000000000000000000000000000@410@410@410L309@0000`000010000:00000`000020000
5P0000`0000H00004P0000`0000100006`00010000000000000002D0000<00000@0005@0001/0000
I0000?X0002R00007@40004000000==1003C@MX0002D0@001@0004`0000000000000000000000000
000005P0000_07<0:@0P05T0`<090000300000/0000800005`0001H0000<000000000180000<0000
0P0000`0000@000000000000000U0000300000d0080X000030000040000>000050000000000@0000
5000
\>"], "Graphics",
  ImageSize->{360, 196.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Therefore the transfer function of the closed loop is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CLControlObjectTF = 
      FeedbackConnect[ControlObjectTF, pi, {1}, {2}] // Simplify\)], "Input"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(2\ \@h0\ s\)\/\(\(-2\)\ h0\ k\_i + s\ \((c0 + 2\ A\ \@h0\ s - 2\ \
h0\ k\_p)\)\), \(2\ h0\ s\)\/\(2\ h0\ k\_i - s\ \((c0 + 2\ A\ \@h0\ s - 2\ h0\
\ k\_p)\)\)}}]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Introducing pole displacements ", "Section"],

Cell[TextData[{
  "In order to determine the gains, ",
  Cell[BoxData[
      \(k\_p\)]],
  " and ",
  Cell[BoxData[
      \(k\_i\)]],
  ", we represent this closed loop system  in equation form instead of  \
transfer function form:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // EquationForm\)], "Input"],

Cell[BoxData[
    TagBox[
      FormBox[
        SubsuperscriptBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(\(2\ \@h0\ \[ScriptS]\)\/\(\[ScriptS]\ \((c0 + 
                                2\ A\ \@h0\ \[ScriptS] - 2\ h0\ k\_p)\) - 
                          2\ h0\ k\_i\)\), \(\(2\ h0\ \[ScriptS]\)\/\(2\ h0\ \
k\_i - \[ScriptS]\ \((c0 + 2\ A\ \@h0\ \[ScriptS] - 2\ h0\ k\_p)\)\)\)}
                  },
                AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
            "TraditionalForm"], 
          FormBox[
            StyleBox["\<\"\[InvisibleSpace]\"\>",
              ShowStringCharacters->False],
            "TraditionalForm"], 
          FormBox[
            StyleBox["\<\"\[ScriptCapitalT]\"\>",
              Editable->False,
              ShowStringCharacters->False],
            "TraditionalForm"],
          MultilineFunction->None],
        "TraditionalForm"],
      (TransferFunction[ s, 
        SlotSequence[ 1]]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and compare its denominator, a second  order polynomial of ",
  StyleBox["s",
    FontSlant->"Italic"],
  ","
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Denominator[%[s]]\)\[LeftDoubleBracket]1, 
      1\[RightDoubleBracket]\)], "Input",
  CellTags->"6.5"],

Cell[BoxData[
    \(\(-2\)\ h0\ k\_i + 
      s\ \((c0 + 2\ A\ \@h0\ s - 2\ h0\ k\_p)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(d\_1 = \((Sum[
          Coefficient[%, s, j]/Coefficient[%, s, 2] s\^j, {j, 0, 
            2}])\)\)], "Input"],

Cell[BoxData[
    \(s\^2 - \(\@h0\ k\_i\)\/A + \(s\ \((c0 - 2\ h0\ k\_p)\)\)\/\(2\ A\ \
\@h0\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["with",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["the",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["polynomial",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["of",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["s",
          FontFamily->"Times New Roman",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["containing",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["the",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["two",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["poles",
          FontFamily->"Times New Roman"]}], 
      StyleBox[",",
        FontFamily->"Times New Roman"], 
      StyleBox[" ",
        FontFamily->"Times New Roman"], 
      RowBox[{
        StyleBox[\(p\_1\),
          FontFamily->"Times New Roman",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox["and",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox[\(p\_2\),
          FontFamily->"Times New Roman",
          FontSlant->"Italic"]}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d\_2 = \(\((s + p\_1)\)\(\ \)\((s + p\_2)\)\(\ \)\)\)], "Input",
  CellTags->"6.5"],

Cell[BoxData[
    \(\((s + p\_1)\)\ \((s + p\_2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[CoefficientList[d\_1 - d\_2, s] \[Equal] 0, {k\_i, k\_p}] // 
      Simplify\)], "Input",
  CellTags->"6.5"],

Cell[BoxData[
    \({{k\_i \[Rule] \(-\(\(A\ p\_1\ p\_2\)\/\@h0\)\), 
        k\_p \[Rule] \(-\(\(A\ \((\(-\(c0\/\(2\ A\ \@h0\)\)\) + p\_1 + 
                      p\_2)\)\)\/\@h0\)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
    "So", " ", "the", " ", "gains", " ", "can", " ", "be", " ", "expressed", 
      " ", "by", " ", "the", " ", "design", " ", "parameters", " ", 
      StyleBox[\(p\_1\),
        FontSlant->"Italic"], " ", "and", " ", 
      StyleBox[\(p\_2\),
        FontSlant->"Italic"]}]], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \({k\_i, k\_p} = {k\_i, k\_p} /. %[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({\(-\(\(A\ p\_1\ p\_2\)\/\@h0\)\), \(-\(\(A\ \((\(-\(c0\/\(2\ A\ \@h0\)\
\)\) + p\_1 + p\_2)\)\)\/\@h0\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Substituting these expressions into the transfer function of the closed loop \
, we get\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CLControlObjectTF // Simplify\)], "Input"],

Cell[BoxData[
    \(TransferFunction[
      s, {{s\/\(A\ \((s + p\_1)\)\ \((s + p\_2)\)\), \(-\(\(\@h0\ s\)\/\(A\ \
\((s + p\_1)\)\ \((s + p\_2)\)\)\)\)}}]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation of the linearized closed loop response", "Section"],

Cell["\<\
Let us suppose, that the input flow rate changes like a step function, then \
the output of the linearized cloosed loop system can be determinated in \
symbolic form\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(OutputResponse[%, {9. \ UnitStep[t - 1], 0}, t] // ComplexExpand\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \({\(\((9.`\ \[ExponentialE]\^\(\(-\((\(-1\) + t)\)\)\ p\_1\) - 9.`\ \
\[ExponentialE]\^\(\(-\((\(-1\) + t)\)\)\ p\_2\))\)\ UnitStep[\(-1\) + t]\)\/\
\(\(-1.`\)\ A\ p\_1 + 1.`\ A\ p\_2\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Applying numerical values, one may simulate the response of the PI controlled \
linearized system:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p1 = 
        Plot[Evaluate[% /. {A \[Rule] 10. , p\_1 \[Rule] 2. , 
                p\_2 \[Rule] 1. }], {t, 0, 10}, 
          PlotStyle \[Rule] {RGBColor[1, 0, 0]}, 
          PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 2.61603 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .14552 -24 -4.5 ]
[.01131 .14552 0 4.5 ]
[.01131 .27632 -18 -4.5 ]
[.01131 .27632 0 4.5 ]
[.01131 .40712 -24 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .53792 -18 -4.5 ]
[.01131 .53792 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14552 m
.03006 .14552 L
s
[(0.05)] .01131 .14552 1 0 Mshowa
.02381 .27632 m
.03006 .27632 L
s
[(0.1)] .01131 .27632 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(0.15)] .01131 .40712 1 0 Mshowa
.02381 .53792 m
.03006 .53792 L
s
[(0.2)] .01131 .53792 1 0 Mshowa
.125 Mabswid
.02381 .04088 m
.02756 .04088 L
s
.02381 .06704 m
.02756 .06704 L
s
.02381 .0932 m
.02756 .0932 L
s
.02381 .11936 m
.02756 .11936 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .19784 m
.02756 .19784 L
s
.02381 .224 m
.02756 .224 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .30248 m
.02756 .30248 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .3548 m
.02756 .3548 L
s
.02381 .38096 m
.02756 .38096 L
s
.02381 .43328 m
.02756 .43328 L
s
.02381 .45944 m
.02756 .45944 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51176 m
.02756 .51176 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .59024 m
.02756 .59024 L
s
.02381 .6164 m
.02756 .6164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .03759 L
.12507 .15007 L
.13492 .32067 L
.14415 .43386 L
.14911 .47956 L
.15453 .51926 L
.15965 .54827 L
.1644 .56877 L
.16682 .57709 L
.1691 .58373 L
.17337 .59327 L
.17576 .59712 L
.17796 .59979 L
.17911 .60087 L
.18037 .60182 L
.18169 .60256 L
.18292 .60302 L
.18418 .60327 L
.18482 .60332 L
.18552 .60331 L
.18676 .60314 L
.18793 .6028 L
.1886 .60254 L
.1893 .60221 L
.19055 .60148 L
.19337 .59921 L
.19582 .5966 L
.1981 .59368 L
.20328 .58549 L
.21225 .56703 L
.22183 .54294 L
.26333 .41849 L
.30331 .3057 L
.34178 .21991 L
.36126 .18525 L
.3827 .15322 L
.4221 .10837 L
.44155 .09168 L
.46244 .07695 L
.48219 .06556 L
Mistroke
.50372 .05546 L
.54348 .04172 L
.56319 .03672 L
.58417 .0324 L
.60419 .02907 L
.62581 .02617 L
.66593 .02224 L
.68591 .02082 L
.70698 .01961 L
.74501 .018 L
.76456 .01739 L
.78548 .01687 L
.80533 .01646 L
.8269 .01611 L
.86679 .01563 L
.88661 .01546 L
.90763 .01531 L
.92583 .01521 L
.94543 .01512 L
.97619 .01501 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B`3oool400000340oooo0`00000^0?ooo`<00000
<03oool2000002d0oooo1@0000020?ooo`800000103oool004/0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool0
0000;P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool004`0
oooo00<000000?ooo`3oool0;`3oool5000002h0oooo00@000000?ooo`3oool00000;P3oool01000
0000oooo0?ooo`00000^0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`010?ooo`00C@3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000002l0oooo0`00
000`0?ooo`800000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0@3oool004/0oooo00@000000?ooo`3oool00000<03oool00`000000oooo0000000`0?ooo`030000
003oool0oooo02h0oooo00@000000?ooo`3oool00000;P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00@3oool004`0oooo0P00000b0?ooo`800000<03oool3000002l0
oooo0P00000^0?ooo`800000103oool2000000@0oooo003o0?ooob40oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001@0oooo
1`00000J0?l00;@00000<03o0007000000006`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06P3o00090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo000K
0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02`3oool>0?l001H0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`006`3oool00`000000oooo0?ooo`0F0?oo
o`030?l0003oool0oooo0880oooo203o001O0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo07`0oooo1P3o001W0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`030?l0
003oool0oooo07L0oooo1@3o001]0?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo0740oooo1P3o001b0?ooo`006`3oool2000001L0oooo00<0o`000?ooo`3oool0K@3oool4
0?l007P0oooo000K0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0JP3oool30?l0
07`0oooo000K0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0J03oool20?l007l0
oooo000K0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0I@3oool30?l00840oooo
000K0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0HP3oool30?l008@0oooo000K
0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0H03oool20?l008L0oooo000K0?oo
o`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0GP3oool20?l008T0oooo000K0?ooo`80
0000603oool00`3o0000oooo0?ooo`1L0?ooo`030?l0003oool0oooo08T0oooo000K0?ooo`030000
003oool0oooo01L0oooo00<0o`000?ooo`3oool0FP3oool20?l008`0oooo000K0?ooo`030000003o
ool0oooo01L0oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`2<0?ooo`006`3oool0
0`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo05P0oooo00<0o`000?ooo`3oool0S@3oool0
01/0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`1F0?ooo`80o`00T03oool001/0
oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`1D0?ooo`80o`00TP3oool001/0oooo
00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`1B0?ooo`80o`00U03oool001/0oooo0P00
000H0?ooo`030?l0003oool0oooo0540oooo00<0o`000?ooo`3oool0U03oool001/0oooo00<00000
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`1@0?ooo`030?l0003oool0oooo09D0oooo000K0?oo
o`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`2F0?oo
o`006`3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo04h0oooo00<0o`000?ooo`3o
ool0U`3oool001/0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0
003oool0oooo09P0oooo000K0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0C03o
ool00`3o0000oooo0?ooo`2I0?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo04/0oooo00<0o`000?ooo`3oool0VP3oool001/0oooo0P00000H0?ooo`030?l0003oool0oooo
04X0oooo00<0o`000?ooo`3oool0V`3oool001/0oooo00<000000?ooo`3oool0603oool00`3o0000
oooo0?ooo`180?ooo`030?l0003oool0oooo09`0oooo000K0?ooo`030000003oool0oooo01P0oooo
00<0o`000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`2M0?ooo`006`3oool00`000000oooo0?oo
o`0H0?ooo`030?l0003oool0oooo04H0oooo00<0o`000?ooo`3oool0WP3oool001/0oooo00<00000
0?ooo`3oool0603oool00`3o0000oooo0?ooo`160?ooo`030?l0003oool0oooo09h0oooo00020?oo
o`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo04D0oooo00<0o`000?ooo`3oool0W`3oool000050?ooo`000000oooo0?oo
o`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0603oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo0:00oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`020?ooo`8000006@3oool00`3o0000oooo0?ooo`130?ooo`030?l0003oool0oooo0:40oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool2000000D0
oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`120?ooo`030?l0003oool0oooo0:80
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0@@3oool00`3o
0000oooo0?ooo`2S0?ooo`000P3oool2000000X0oooo0P0000040?ooo`<00000103oool00`000000
oooo0?ooo`0H0?ooo`030?l0003oool0oooo0400oooo00<0o`000?ooo`3oool0Y03oool001/0oooo
00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`100?ooo`030?l0003oool0oooo0:@0oooo
000K0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?oo
o`2U0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03h0oooo00<0o`00
0?ooo`3oool0YP3oool001/0oooo0P00000I0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?oo
o`3oool0YP3oool001/0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0m0?ooo`03
0?l0003oool0oooo0:L0oooo000K0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0
?@3oool00`3o0000oooo0?ooo`2W0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo03`0oooo00<0o`000?ooo`3oool0Z03oool001/0oooo00<000000?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0:T0oooo000K0?ooo`030000003oool0oooo
01P0oooo00<0o`000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`2Y0?ooo`006`3oool00`000000
oooo0?ooo`0I0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool0ZP3oool001/0oooo
0P00000J0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool0ZP3oool001/0oooo00<0
00000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0:/0oooo000K
0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`2/
0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo03L0oooo00<0o`000?oo
o`3oool0[03oool001/0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0f0?ooo`03
0?l0003oool0oooo0:d0oooo000K0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0
=P3oool00`3o0000oooo0?ooo`2]0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo03D0oooo00<0o`000?ooo`3oool0[P3oool001/0oooo0P00000J0?ooo`030?l0003oool0
oooo03D0oooo00<0o`000?ooo`3oool0[P3oool001/0oooo00<000000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo0:l0oooo000K0?ooo`030000003oool0oooo01T0
oooo00<0o`000?ooo`3oool0=03oool00`3o0000oooo0?ooo`2_0?ooo`006`3oool00`000000oooo
0?ooo`0I0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0/03oool001/0oooo00<0
00000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0oooo0;00oooo000K
0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`2a
0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0380oooo00<0o`000?oo
o`3oool0/@3oool001/0oooo0P00000J0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3o
ool0/P3oool001/0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0a0?ooo`030?l0
003oool0oooo0;80oooo000K0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0<03o
ool00`3o0000oooo0?ooo`2c0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0
oooo0300oooo00<0o`000?ooo`3oool0/`3oool001/0oooo00<000000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0;<0oooo00080?ooo`800000103oool2000000<0
oooo1@0000030?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000
oooo0?ooo`2d0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo0;@0
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool2000001/0
oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`2e0?ooo`001`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`3o0000
oooo0?ooo`0]0?ooo`030?l0003oool0oooo0;D0oooo00070?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02`0
oooo00<0o`000?ooo`3oool0]P3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0]P3oool001/0oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0;L0oooo000K
0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`2g
0?ooo`006`3oool2000001/0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`2h0?oo
o`006`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o
ool0^03oool001/0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0
003oool0oooo0;P0oooo000K0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`2i0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0
oooo02T0oooo00<0o`000?ooo`3oool0^@3oool001/0oooo00<000000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0;T0oooo000K0?ooo`030000003oool0oooo01X0
oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`2j0?ooo`006`3oool2000001/0oooo
00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`2j0?ooo`006`3oool00`000000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0^P3oool001/0oooo00<00000
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo0;/0oooo000K0?oo
o`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`2k0?oo
o`006`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3o
ool0^`3oool001/0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0
003oool0oooo0;`0oooo000K0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`2l0?ooo`006`3oool2000001`0oooo00<0o`000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`2l0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo
02@0oooo00<0o`000?ooo`3oool0_@3oool001/0oooo00<000000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo0;d0oooo000K0?ooo`030000003oool0oooo01/0oooo
00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`2m0?ooo`006`3oool00`000000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0_P3oool001/0oooo00<00000
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0;h0oooo000K0?oo
o`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`2n0?oo
o`006`3oool2000001d0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`2o0?ooo`00
6`3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0
_`3oool001/0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0;l0oooo000K0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`300?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
0200oooo00<0o`000?ooo`3oool0`03oool00080oooo0P0000040?ooo`8000000`3oool500000080
oooo0P0000050?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0803oool00`3o0000
oooo0?ooo`300?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`310?ooo`0000D0oooo0000003oool0oooo0000000:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000001d0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`310?ooo`0000D0oooo0000003oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo01`0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`310?ooo`0000D0oooo0000003oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?oo
o`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0`P3oool00080oooo0P00000:0?ooo`80
0000103oool3000000@0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo0<80oooo000K0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`320?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo01`0oooo00<0o`000?ooo`3oool0``3oool001/0oooo00<000000?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0<<0oooo000K0?ooo`8000007P3oool00`3o
0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0<<0oooo000K0?ooo`030000003oool0oooo01d0
oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`340?ooo`006`3oool00`000000oooo
0?ooo`0M0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0a03oool001/0oooo00<0
00000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0<@0oooo000K
0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`35
0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?oo
o`3oool0a@3oool001/0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo0<D0oooo000K0?ooo`8000007`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0<H0oooo000K0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`360?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo01P0oooo00<0o`000?ooo`3oool0aP3oool001/0oooo00<000000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0<L0oooo000K0?ooo`030000003oool0oooo01h0
oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`370?ooo`006`3oool00`000000oooo
0?ooo`0N0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0a`3oool001/0oooo00<0
00000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0<P0oooo000K
0?ooo`8000007`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0<P0oooo000K0?oo
o`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`380?oo
o`006`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3o
ool0b@3oool001/0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo0<T0oooo000K0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool0503o
ool00`3o0000oooo0?ooo`390?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo01<0oooo00<0o`000?ooo`3oool0bP3oool001/0oooo00<000000?ooo`3oool07`3oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0<X0oooo000K0?ooo`8000008@3oool00`3o0000
oooo0?ooo`0B0?ooo`030?l0003oool0oooo0<X0oooo000K0?ooo`030000003oool0oooo0200oooo
00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`3;0?ooo`006`3oool00`000000oooo0?oo
o`0P0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0b`3oool001/0oooo00<00000
0?ooo`3oool0803oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0</0oooo000K0?oo
o`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`3<0?oo
o`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0c03oool000L0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`3<0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo0P00000R0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0c@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0240oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`3=0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0<d0oooo00080?ooo`80
00002P3oool2000000D0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0<h0oooo000K0?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`3>0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0c`3oool001/0oooo00<000000?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0<l0oooo000K0?ooo`8000008`3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0=00oooo000K0?ooo`030000003oool0oooo0280
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`3@0?ooo`006`3oool00`000000oooo
0?ooo`0R0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0d03oool001/0oooo00<0
00000?ooo`3oool08`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0=40oooo000K
0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`3A
0?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool0dP3oool001/0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo0=80oooo000K0?ooo`8000009@3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo0=<0oooo000K0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`3D0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0
oooo0080oooo0P3o003F0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`@0o`00f03oool001/0
oooo00<000000?ooo`3oool09`3oool20?l00=T0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -0.020676, \
0.0394728, 0.00143703}}]
}, Open  ]],

Cell["\<\
Now, the level returns back to the original set point value, despite of the \
new input flow rate.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation of the nonlinear closed loop response", "Section"],

Cell["The state space form of the controller", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StateSpace[pi] // EquationForm\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[GridBox[{
              {
                RowBox[{\(\[ScriptX]\& . \), "=", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"0"}
                        },
                      ColumnAlignments->{Decimal},
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptX]", "+", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1"}
                        },
                      ColumnAlignments->{Decimal},
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptU]"}]},
              {
                RowBox[{"\[ScriptY]", "=", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(-\(\(A\ p\_1\ p\_2\)\/\@h0\)\)}
                        },
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptX]", "+", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(\(c0 - 2\ A\ \@h0\ p\_1 - 
                                2\ A\ \@h0\ p\_2\)\/\(2\ h0\)\)}
                        },
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptU]"}]}
              },
            ColumnAlignments->{"="},
            AllowScriptLevelChange->False],
          "TraditionalForm"],
        (EquationForm[ 
          StateSpace[ 
            SlotSequence[ 1]]]&)], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Therefore, the explicit form of y[u] is ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[t_] = 
      c0\  - First[Flatten[%[\([3]\)]]]\ z[t] - \(\(First[
            Flatten[%[\([4]\)]]]\) \((h[t] - h0)\)\(\[NoBreak]\)\)\)], "Input"],

Cell[BoxData[
    \(c0 - \(\((\(-h0\) + h[t])\)\ \((c0 - 2\ A\ \@h0\ p\_1 - 2\ A\ \@h0\ \
p\_2)\)\)\/\(2\ h0\) + \(A\ p\_1\ p\_2\ z[t]\)\/\@h0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where the corresponding variables are y\[Rule]c[t ]- c0 and u\[Rule]h[t] - \
h0  and the negative feedback was taken into consideration. To avoid integral \
equation, a new variable, ",
  StyleBox["z",
    FontSlant->"Italic"],
  " can be introduced:  "
}], "Text"],

Cell[BoxData[
    StyleBox[\(dz\/dt = \ h[t] - h0\),
      FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Center],

Cell["with the initial condition", "Text"],

Cell[TextData[StyleBox["z[0] = 0",
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Center],

Cell["Then the nonlinear model equation with PI controller:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"deq", "=", 
      RowBox[{\(\(\(-c[t]\)\ \@h[t] + Qin0 + 9.  UnitStep[t - 1]\)\/A\), "==",
         
        RowBox[{
          SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\(Qin0 + 
            9.`\ UnitStep[\(-1\) + 
                  t] + \@h[t]\ \((\(-c0\) + \(\((\(-h0\) + h[t])\)\ \((c0 - 2\
\ A\ \@h0\ p\_1 - 2\ A\ \@h0\ p\_2)\)\)\/\(2\ h0\) - \(A\ p\_1\ p\_2\ \
z[t]\)\/\@h0)\)\)\/A\), "==", 
      RowBox[{
        SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(deqz = \(z'\)[t] == h[t] - h0\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["z", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "==", \(\(-h0\) + h[t]\)}]], "Output"]
}, Open  ]],

Cell["Applying numerical values", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ndeq = 
      deq /. {A \[Rule] 10. , h0 \[Rule] 9. , Qin0 \[Rule] 9. , 
          c0 \[Rule] 3. , p\_1 \[Rule] 2. , p\_2 \[Rule] 1. }\)], "Input"],

Cell[BoxData[
    RowBox[{\(0.1`\ \((\(\(9.`\)\(\[InvisibleSpace]\)\) + 
            9.`\ UnitStep[\(-1\) + t] + \@h[t]\ \((\(-3.`\) - 
                  9.833333333333332`\ \((\(-9.`\) + h[t])\) - 
                  6.666666666666666`\ z[t])\))\)\), "==", 
      RowBox[{
        SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ndeqz = deqz /. h0 \[Rule] 9. \)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["z", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
      "==", \(\(-9.`\) + h[t]\)}]], "Output"]
}, Open  ]],

Cell["The solutions are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(numSol = 
      NDSolve[{Ndeq, Ndeqz, h[0] \[Equal] 9. , z[0] \[Equal] 0}, {h, z}, {t, 
          0, 10}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"h", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"z", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p2 = 
        Plot[Evaluate[\((h[t] /. numSol)\) - 9. ], {t, 0, 10}, 
          PlotStyle \[Rule] {RGBColor[0, 0, 1]}, Frame \[Rule] True, 
          PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 2.64091 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14676 -24 -4.5 ]
[-0.0125 .14676 0 4.5 ]
[-0.0125 .27881 -18 -4.5 ]
[-0.0125 .27881 0 4.5 ]
[-0.0125 .41085 -24 -4.5 ]
[-0.0125 .41085 0 4.5 ]
[-0.0125 .5429 -18 -4.5 ]
[-0.0125 .5429 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14676 m
.00625 .14676 L
s
[(0.05)] -0.0125 .14676 1 0 Mshowa
0 .27881 m
.00625 .27881 L
s
[(0.1)] -0.0125 .27881 1 0 Mshowa
0 .41085 m
.00625 .41085 L
s
[(0.15)] -0.0125 .41085 1 0 Mshowa
0 .5429 m
.00625 .5429 L
s
[(0.2)] -0.0125 .5429 1 0 Mshowa
.125 Mabswid
0 .04112 m
.00375 .04112 L
s
0 .06753 m
.00375 .06753 L
s
0 .09394 m
.00375 .09394 L
s
0 .12035 m
.00375 .12035 L
s
0 .17317 m
.00375 .17317 L
s
0 .19958 m
.00375 .19958 L
s
0 .22599 m
.00375 .22599 L
s
0 .2524 m
.00375 .2524 L
s
0 .30521 m
.00375 .30521 L
s
0 .33162 m
.00375 .33162 L
s
0 .35803 m
.00375 .35803 L
s
0 .38444 m
.00375 .38444 L
s
0 .43726 m
.00375 .43726 L
s
0 .46367 m
.00375 .46367 L
s
0 .49008 m
.00375 .49008 L
s
0 .51649 m
.00375 .51649 L
s
0 .56931 m
.00375 .56931 L
s
0 .59571 m
.00375 .59571 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14676 m
1 .14676 L
s
.99375 .27881 m
1 .27881 L
s
.99375 .41085 m
1 .41085 L
s
.99375 .5429 m
1 .5429 L
s
.125 Mabswid
.99625 .04112 m
1 .04112 L
s
.99625 .06753 m
1 .06753 L
s
.99625 .09394 m
1 .09394 L
s
.99625 .12035 m
1 .12035 L
s
.99625 .17317 m
1 .17317 L
s
.99625 .19958 m
1 .19958 L
s
.99625 .22599 m
1 .22599 L
s
.99625 .2524 m
1 .2524 L
s
.99625 .30521 m
1 .30521 L
s
.99625 .33162 m
1 .33162 L
s
.99625 .35803 m
1 .35803 L
s
.99625 .38444 m
1 .38444 L
s
.99625 .43726 m
1 .43726 L
s
.99625 .46367 m
1 .46367 L
s
.99625 .49008 m
1 .49008 L
s
.99625 .51649 m
1 .51649 L
s
.99625 .56931 m
1 .56931 L
s
.99625 .59571 m
1 .59571 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .03781 L
.12507 .15134 L
.13492 .32324 L
.14415 .43682 L
.14911 .48246 L
.15453 .52192 L
.15965 .55059 L
.1644 .57069 L
.16682 .5788 L
.1691 .58522 L
.17337 .59435 L
.17576 .59797 L
.17796 .60042 L
.17911 .6014 L
.18037 .60223 L
.18169 .60284 L
.18292 .60318 L
.18418 .60332 L
.18482 .60331 L
.18552 .60323 L
.18676 .60295 L
.18793 .60252 L
.1893 .60181 L
.19055 .60097 L
.19337 .59848 L
.1982 .59248 L
.20328 .58411 L
.22183 .54092 L
.25994 .42748 L
.3005 .31348 L
.33955 .22652 L
.35946 .19111 L
.38104 .1588 L
.42103 .113 L
.4409 .09577 L
.46195 .08071 L
.49983 .06017 L
.51928 .05222 L
.54017 .0452 L
.55992 .03977 L
Mistroke
.58145 .03494 L
.62121 .02832 L
.64092 .02589 L
.66191 .02377 L
.68192 .02213 L
.70354 .02069 L
.74366 .01872 L
.76364 .01799 L
.78472 .01737 L
.82274 .01653 L
.84229 .0162 L
.86322 .01592 L
.88307 .01571 L
.90463 .01552 L
.92399 .01537 L
.94453 .01525 L
.97619 .01511 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00803oool2000002h0oooo1000000`0?ooo`<00000
;03oool300000300oooo0P00000[0?ooo`D000000P3oool2000000@0oooo000O0?ooo`040000003o
ool0oooo000002d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0[0?ooo`040000
003oool0oooo000002h0oooo00@000000?ooo`3oool00000;03oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00@3oool001l0oooo00@000000?ooo`3oool00000;P3oool0
0`000000oooo0?ooo`0^0?ooo`D00000;03oool010000000oooo0?ooo`00000^0?ooo`040000003o
ool0oooo000002`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040
oooo000O0?ooo`040000003oool0oooo000002l0oooo00<000000?ooo`3oool0;@3oool010000000
oooo0?ooo`00000]0?ooo`<00000<03oool2000002d0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0040oooo000O0?ooo`040000003oool0oooo000002d0oooo00@00000
0?ooo`3oool00000;`3oool00`000000oooo0000000^0?ooo`030000003oool0oooo02h0oooo00@0
00000?ooo`3oool00000;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00@3oool00200oooo0P00000_0?ooo`800000<@3oool2000002h0oooo0`00000_0?ooo`800000
;03oool2000000@0oooo0P0000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo000000D000000@3oool001/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool100000040oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?oo
o`4000000@3oool001<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oo
o`40oooo0@0000010?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`800000103ooolJ0000
ojT0oooo=@000?l40?ooo`8000000@3oool001<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0980oooo5@000?lj0?ooo`4000000@3oool001<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
08P0oooo2P000?m?0?ooo`4000000@3oool001@0oooo0P0000050?ooo`030000003oool0oooo01`0
oooo00<0003o0?ooo`3oool0O@3oool;0000oeT0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo07P0oooo1@000?mT0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`1c0?ooo`D0003oJ@3oool100000040oooo000K
0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0KP3oool50000ofh0oooo0@000001
0?ooo`006`3oool2000001d0oooo00<0003o0?ooo`3oool0K03oool20000og80oooo0P0000010?oo
o`006`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo06P0oooo10000?me0?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`1U0?ooo`<0003o
N@3oool100000040oooo000K0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0H`3o
ool20000og`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0
oooo0640oooo0P000?mn0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo07h0oooo0@0000010?ooo`006`3oool2000001d0
oooo00<0003o0?ooo`3oool0GP3oool20000oh00oooo0P0000010?ooo`006`3oool00`000000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo05`0oooo0P000?n30?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`1J0?ooo`80003oQ@3oool100000040oooo000K
0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0F03oool20000ohL0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo05H0oooo0P000?n90?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`1D0?ooo`80
003oR`3oool100000040oooo000K0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
D`3oool00`000?l0oooo0?ooo`2;0?ooo`4000000@3oool001/0oooo0P00000M0?ooo`030000o`3o
ool0oooo0540oooo0P000?n=0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`1?0?ooo`030000o`3oool0oooo08h0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo04h0oooo00<0003o0?ooo`3oool0S`3oool10000
0040oooo000K0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0C03oool20000oi80
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo04/0oooo
00<0003o0?ooo`3oool0TP3oool100000040oooo000K0?ooo`030000003oool0oooo01d0oooo00<0
003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`2C0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo09@0oooo0@000001
0?ooo`006`3oool2000001h0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`2D0?oo
o`8000000@3oool001/0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`170?ooo`03
0000o`3oool0oooo09H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000
o`3oool0oooo04L0oooo00<0003o0?ooo`3oool0UP3oool100000040oooo000K0?ooo`030000003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`2G0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`150?ooo`030000o`3oool0
oooo09P0oooo0@0000010?ooo`000P3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`140?ooo`030000o`3oool0oooo
09T0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo04<0oooo00<0003o0?ooo`3oool0VP3oool100000040oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`800000
7P3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo09X0oooo0P0000010?ooo`0000D0
oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`03
0000003oool0oooo01d0oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`2K0?ooo`40
00000@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`110?oo
o`030000o`3oool0oooo09`0oooo0@0000010?ooo`000P3oool2000000X0oooo0P0000040?ooo`<0
0000103oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3o
ool0W@3oool100000040oooo000K0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0
?`3oool00`000?l0oooo0?ooo`2N0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo09h0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo03h0oooo00<0003o0?ooo`3oool0W`3oool1
00000040oooo000K0?ooo`8000007P3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo
09l0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo03d0
oooo00<0003o0?ooo`3oool0X03oool100000040oooo000K0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`2Q0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3oool0oooo0:80oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo03X0oooo00<0003o
0?ooo`3oool0XP3oool100000040oooo000K0?ooo`030000003oool0oooo01h0oooo00<0003o0?oo
o`3oool0>@3oool00`000?l0oooo0?ooo`2S0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo0:@0oooo0@0000010?ooo`00
6`3oool2000001l0oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?ooo`2S0?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3o
ool0oooo0:D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0
oooo03L0oooo00<0003o0?ooo`3oool0Y@3oool100000040oooo000K0?ooo`030000003oool0oooo
01h0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`2V0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo0:H0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo03D0oooo
00<0003o0?ooo`3oool0Y`3oool100000040oooo000K0?ooo`030000003oool0oooo01h0oooo00<0
003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`2W0?ooo`4000000@3oool001/0oooo0P00000O
0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0Y`3oool200000040oooo000K0?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`2X0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0c0?ooo`03
0000o`3oool0oooo0:T0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo0380oooo00<0003o0?ooo`3oool0Z@3oool100000040oooo000K0?ooo`030000003o
ool0oooo01l0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`2Z0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0
oooo0:X0oooo0@0000010?ooo`006`3oool200000200oooo00<0003o0?ooo`3oool0<03oool00`00
0?l0oooo0?ooo`2Z0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool07`3oool00`000?l0
oooo0?ooo`0`0?ooo`030000o`3oool0oooo0:/0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`0O0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool0[03oool100000040oooo
000K0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`2/0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0^
0?ooo`030000o`3oool0oooo0:d0oooo0@0000010?ooo`00203oool2000000@0oooo0P0000030?oo
o`D000000`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?oo
o`3oool0[@3oool100000040oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?oo
o`3oool0[@3oool100000040oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool200000200oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`2]0?oo
o`8000000@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`2^0?oo
o`4000000@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`2_0?oo
o`4000000@3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0[`3oool100000040oooo000K0?ooo`030000
003oool0oooo01l0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`2`0?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo0;00oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0
oooo02T0oooo00<0003o0?ooo`3oool0/@3oool100000040oooo000K0?ooo`8000008@3oool00`00
0?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0;00oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool0/P3oool100000040
oooo000K0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo
0?ooo`2b0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?oo
o`0X0?ooo`030000o`3oool0oooo0;80oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0/`3oool100000040oooo000K0?oo
o`030000003oool0oooo0200oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`2c0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo0;<0oooo0@0000010?ooo`006`3oool200000240oooo00<0003o0?ooo`3oool0
9P3oool00`000?l0oooo0?ooo`2c0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo0;@0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0]@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`2e0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0803oool00`000?l0
oooo0?ooo`0U0?ooo`030000o`3oool0oooo0;D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0]P3oool100000040oooo
000K0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?oo
o`2f0?ooo`4000000@3oool001/0oooo0P00000R0?ooo`030000o`3oool0oooo02<0oooo00<0003o
0?ooo`3oool0]@3oool200000040oooo000K0?ooo`030000003oool0oooo0240oooo00<0003o0?oo
o`3oool08P3oool00`000?l0oooo0?ooo`2g0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0;L0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0
^03oool100000040oooo000K0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`2h0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0;P0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0^@3oool10000
0040oooo000K0?ooo`8000008P3oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo0;P0
oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0200oooo
00<0003o0?ooo`3oool0^@3oool100000040oooo000K0?ooo`030000003oool0oooo0240oooo00<0
003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`2j0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0;X0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?oo
o`3oool0^P3oool100000040oooo00020?ooo`800000103oool2000000<0oooo1@0000020?ooo`80
00001@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3o
ool0^`3oool100000040oooo00001@3oool000000?ooo`3oool0000000X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo0;/0oooo0@0000010?ooo`0000D0oooo0000003o
ool0oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool20000
02<0oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`2k0?ooo`8000000@3oool00005
0?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0_03oool10000
0040oooo00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0703oool00`00
0?l0oooo0?ooo`2l0?ooo`4000000@3oool00080oooo0P00000:0?ooo`800000103oool3000000@0
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0;d0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01/0oooo
00<0003o0?ooo`3oool0_@3oool100000040oooo000K0?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`2m0?ooo`4000000@3oool001/0oooo0P00000S
0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0_@3oool200000040oooo000K0?oo
o`030000003oool0oooo0280oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`2n0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo0;h0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0_`3oool100000040oooo000K0?ooo`030000003o
ool0oooo0280oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`2o0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0
oooo0;l0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
01L0oooo00<0003o0?ooo`3oool0`03oool100000040oooo000K0?ooo`800000903oool00`000?l0
oooo0?ooo`0G0?ooo`030000o`3oool0oooo0;l0oooo0P0000010?ooo`006`3oool00`000000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0`03oool100000040oooo
000K0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?oo
o`310?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000o`3oool0oooo0<40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0`@3oool100000040oooo000K0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`320?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0<80oooo0@0000010?ooo`006`3oool2000002@0oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`320?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0<<0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0``3oool10000
0040oooo000K0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`340?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0903oool00`000?l0oooo
0?ooo`0B0?ooo`030000o`3oool0oooo0<@0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0a03oool100000040oooo000K
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`35
0?ooo`4000000@3oool001/0oooo0P00000V0?ooo`030000o`3oool0oooo0100oooo00<0003o0?oo
o`3oool0a03oool200000040oooo000K0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`350?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0<H0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0aP3o
ool100000040oooo000K0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`360?ooo`4000000@3oool000P0oooo0P0000040?ooo`8000000`3oool40000
00@0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0<L0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0<L0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo0P00000W0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0aP3oool20000
0040oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0b03oool10000
0040oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0b03oool1
00000040oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo0<P0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0b@3oool100000040
oooo000K0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`390?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0<T0oooo0@0000010?ooo`006`3oool2000002P0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`390?ooo`8000000@3oool001/0oooo00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0<X0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0bP3oool100000040oooo000K0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`3;0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0</0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0c03oool1
00000040oooo000K0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`3=0?ooo`4000000@3oool001/0oooo0P00000[0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0c@3oool200000040oooo000K0?ooo`030000003oool0oooo02/0oooo
10000?oA0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0;03oool20000om80oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool001/0ooooo`00000500000040oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.35193, -0.0265196, \
0.0404426, 0.00145847}}]
}, Open  ]],

Cell["\<\
Comparing the responses of the linearized and nonlinear model, we get \
practically identical responses:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[p1, p2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 2.61603 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .14552 -24 -4.5 ]
[.01131 .14552 0 4.5 ]
[.01131 .27632 -18 -4.5 ]
[.01131 .27632 0 4.5 ]
[.01131 .40712 -24 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .53792 -18 -4.5 ]
[.01131 .53792 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14552 m
.03006 .14552 L
s
[(0.05)] .01131 .14552 1 0 Mshowa
.02381 .27632 m
.03006 .27632 L
s
[(0.1)] .01131 .27632 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(0.15)] .01131 .40712 1 0 Mshowa
.02381 .53792 m
.03006 .53792 L
s
[(0.2)] .01131 .53792 1 0 Mshowa
.125 Mabswid
.02381 .04088 m
.02756 .04088 L
s
.02381 .06704 m
.02756 .06704 L
s
.02381 .0932 m
.02756 .0932 L
s
.02381 .11936 m
.02756 .11936 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .19784 m
.02756 .19784 L
s
.02381 .224 m
.02756 .224 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .30248 m
.02756 .30248 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .3548 m
.02756 .3548 L
s
.02381 .38096 m
.02756 .38096 L
s
.02381 .43328 m
.02756 .43328 L
s
.02381 .45944 m
.02756 .45944 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51176 m
.02756 .51176 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .59024 m
.02756 .59024 L
s
.02381 .6164 m
.02756 .6164 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .03759 L
.12507 .15007 L
.13492 .32067 L
.14415 .43386 L
.14911 .47956 L
.15453 .51926 L
.15965 .54827 L
.1644 .56877 L
.16682 .57709 L
.1691 .58373 L
.17337 .59327 L
.17576 .59712 L
.17796 .59979 L
.17911 .60087 L
.18037 .60182 L
.18169 .60256 L
.18292 .60302 L
.18418 .60327 L
.18482 .60332 L
.18552 .60331 L
.18676 .60314 L
.18793 .6028 L
.1886 .60254 L
.1893 .60221 L
.19055 .60148 L
.19337 .59921 L
.19582 .5966 L
.1981 .59368 L
.20328 .58549 L
.21225 .56703 L
.22183 .54294 L
.26333 .41849 L
.30331 .3057 L
.34178 .21991 L
.36126 .18525 L
.3827 .15322 L
.4221 .10837 L
.44155 .09168 L
.46244 .07695 L
.48219 .06556 L
Mistroke
.50372 .05546 L
.54348 .04172 L
.56319 .03672 L
.58417 .0324 L
.60419 .02907 L
.62581 .02617 L
.66593 .02224 L
.68591 .02082 L
.70698 .01961 L
.74501 .018 L
.76456 .01739 L
.78548 .01687 L
.80533 .01646 L
.8269 .01611 L
.86679 .01563 L
.88661 .01546 L
.90763 .01531 L
.92583 .01521 L
.94543 .01512 L
.97619 .01501 L
Mfstroke
0 0 1 r
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .03759 L
.12507 .15005 L
.13492 .32034 L
.14415 .43285 L
.14911 .47805 L
.15453 .51715 L
.15965 .54554 L
.1644 .56545 L
.16682 .57348 L
.1691 .57985 L
.17337 .58889 L
.17576 .59248 L
.17796 .59491 L
.17911 .59587 L
.18037 .59669 L
.18169 .5973 L
.18292 .59764 L
.18418 .59778 L
.18482 .59776 L
.18552 .59769 L
.18676 .59741 L
.18793 .59698 L
.1893 .59628 L
.19055 .59545 L
.19337 .59299 L
.1982 .58704 L
.20328 .57874 L
.22183 .53596 L
.25994 .42359 L
.3005 .31067 L
.33955 .22453 L
.35946 .18944 L
.38104 .15744 L
.42103 .11208 L
.4409 .095 L
.46195 .08009 L
.49983 .05975 L
.51928 .05187 L
.54017 .04492 L
.55992 .03954 L
Mistroke
.58145 .03475 L
.62121 .02819 L
.64092 .02578 L
.66191 .02369 L
.68192 .02206 L
.70354 .02063 L
.74366 .01868 L
.76364 .01796 L
.78472 .01734 L
.82274 .01651 L
.84229 .01619 L
.86322 .01591 L
.88307 .0157 L
.90463 .01551 L
.92399 .01537 L
.94453 .01525 L
.97619 .0151 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B`3oool400000340oooo0`00000^0?ooo`<00000
<03oool2000002d0oooo1@0000020?ooo`800000103oool004/0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool0
0000;P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool004`0
oooo00<000000?ooo`3oool0;`3oool5000002h0oooo00@000000?ooo`3oool00000;P3oool01000
0000oooo0?ooo`00000^0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`010?ooo`00C@3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000002l0oooo0`00
000`0?ooo`800000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0@3oool004/0oooo00@000000?ooo`3oool00000<03oool00`000000oooo0000000`0?ooo`030000
003oool0oooo02h0oooo00@000000?ooo`3oool00000;P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00@3oool004`0oooo0P00000b0?ooo`800000<03oool3000002l0
oooo0P00000^0?ooo`800000103oool2000000@0oooo003o0?ooob40oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001@0oooo
1`00000J0000ok@000000P3o000^0000o`L00000000K0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?l001D0003o1`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00/0oooo0P3o000C
0000o`l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`006`3oool00`00
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0880oooo103o00060000oed0oooo000K0?ooo`03
0000003oool0oooo01H0oooo00<0003o0?ooo`3oool0O03oool20?l000P0003oH`3oool001/0oooo
00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`1g0?ooo`L0003oJ`3oool001/0oooo00<0
00000?ooo`3oool05P3oool00`000?l0oooo0?ooo`1a0?ooo`<0o`000`000?mb0?ooo`006`3oool2
000001L0oooo00<0003o0?ooo`3oool0K@3oool30?l000@0003oM@3oool001/0oooo00<000000?oo
o`3oool05P3oool00`000?l0oooo0?ooo`1Z0?ooo`80o`0010000?mi0?ooo`006`3oool00`000000
oooo0?ooo`0F0?ooo`030000o`3oool0oooo06P0oooo0P3o00020000ogd0oooo000K0?ooo`030000
003oool0oooo01H0oooo00<0003o0?ooo`3oool0I@3oool20?l000<0003oO`3oool001/0oooo00<0
00000?ooo`3oool05P3oool00`000?l0oooo0?ooo`1R0?ooo`80o`000`000?n20?ooo`006`3oool0
0`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0600oooo0P3o00020000ohD0oooo000K0?oo
o`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0GP3oool20?l00080003oQ`3oool001/0
oooo0P00000H0?ooo`030000o`3oool0oooo05`0oooo00<0o`000000o`000?l0R@3oool001/0oooo
00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1J0?ooo`030?l000000?l0003o08/0oooo
000K0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0F@3oool20000ohd0oooo000K
0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0E`3oool20000ohl0oooo000K0?oo
o`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0o`000?ooo`2?0?oo
o`006`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo05@0oooo0P000?nB0?ooo`00
6`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0580oooo00<0o`000000o`3oool0
T`3oool001/0oooo0P00000H0?ooo`030000o`3oool0oooo0540oooo00<0o`000000o`3oool0U03o
ool001/0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1@0?ooo`030?l000000?l0
oooo09D0oooo000K0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0C`3oool00`3o
0000003o0?ooo`2F0?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo04h0
oooo0P000?nH0?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo04d0oooo
00<0003o0?ooo`3oool0V03oool001/0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`1<0?ooo`030000o`3oool0oooo09T0oooo000K0?ooo`030000003oool0oooo01L0oooo00<0003o
0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`2J0?ooo`006`3oool2000001P0oooo00<0003o0?oo
o`3oool0BP3oool00`000?l0oooo0?ooo`2K0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo04P0oooo00<0003o0?ooo`3oool0W03oool001/0oooo00<000000?ooo`3oool0
603oool00`000?l0oooo0?ooo`170?ooo`030?l000000?l0oooo09d0oooo000K0?ooo`030000003o
ool0oooo01P0oooo00<0003o0?ooo`3oool0AP3oool00`3o0000003o0?ooo`2N0?ooo`006`3oool0
0`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool0WP3oool0
0080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
01P0oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`2O0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0X03o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0080oooo0P00000I0?ooo`030000o`3oool0oooo04<0oooo00<0003o0?ooo`3oool0
X@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`80
00001@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0480oooo00<0o`000000o`3o
ool0XP3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`110?oo
o`030?l000000?l0oooo0:<0oooo00020?ooo`8000002P3oool2000000@0oooo0`0000040?ooo`03
0000003oool0oooo01P0oooo00<0003o0?ooo`3oool0@03oool00`3o0000003o0?ooo`2T0?ooo`00
6`3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0
Y03oool001/0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0o0?ooo`030000o`3o
ool0oooo0:D0oooo000K0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0?P3oool0
0`3o0000003o0?ooo`2V0?ooo`006`3oool2000001T0oooo00<0003o0?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`2V0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo03d0
oooo00<0003o0?ooo`3oool0Y`3oool001/0oooo00<000000?ooo`3oool0603oool00`000?l0oooo
0?ooo`0l0?ooo`030000o`3o0000oooo0:P0oooo000K0?ooo`030000003oool0oooo01P0oooo00<0
003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`2X0?ooo`006`3oool00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool0Z@3oool001/0oooo00<000000?oo
o`3oool0603oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3o0000oooo0:X0oooo000K0?ooo`03
0000003oool0oooo01T0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`2Z0?ooo`00
6`3oool2000001X0oooo00<0003o0?ooo`3oool0>03oool00`000?l0o`000?ooo`2[0?ooo`006`3o
ool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03P0oooo00<0003o0?ooo`3oool0Z`3o
ool001/0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0
oooo0:`0oooo000K0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0=`3oool00`00
0?l0oooo0?ooo`2/0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03H0
oooo00<0003o0?ooo`3oool0[@3oool001/0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`0f0?ooo`030000o`3oool0oooo0:d0oooo000K0?ooo`030000003oool0oooo01T0oooo00<0
003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`2^0?ooo`006`3oool2000001X0oooo00<0003o
0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`2^0?ooo`006`3oool00`000000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo03@0oooo00<0o`000000o`3oool0[`3oool001/0oooo00<000000?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo0:l0oooo000K0?ooo`030000
003oool0oooo01T0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000003o0?ooo`2`0?ooo`006`3o
ool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0/03o
ool001/0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0b0?ooo`030?l000000?l0
oooo0;40oooo000K0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`2a0?ooo`006`3oool2000001X0oooo00<0003o0?ooo`3oool0<@3oool00`3o0000
003o0?ooo`2b0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0340oooo
00<0003o0?ooo`3oool0/P3oool001/0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0`0?ooo`030?l000000?l0oooo0;<0oooo000K0?ooo`030000003oool0oooo01T0oooo00<0003o
0?ooo`3oool0<03oool00`000?l0oooo0?ooo`2c0?ooo`006`3oool00`000000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool0/`3oool000P0oooo0P0000040?ooo`80
00000`3oool5000000<0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo0;@0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3o
ool0]03oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`80
00006`3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo0;D0oooo00070?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo02d0oooo00<0003o0?ooo`3oool0]@3oool000L0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`2f0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000
003oool0oooo01X0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`2f0?ooo`006`3o
ool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0]`3o
ool001/0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0
oooo0;L0oooo000K0?ooo`8000006`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo
0;P0oooo000K0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0
oooo0?ooo`2h0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02T0oooo
00<0003o0?l0003oool0^@3oool001/0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo0;T0oooo000K0?ooo`030000003oool0oooo01X0oooo00<0003o
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`2i0?ooo`006`3oool00`000000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo02P0oooo00<0003o0?l0003oool0^P3oool001/0oooo00<000000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo0;X0oooo000K0?ooo`800000
6`3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo0;X0oooo000K0?ooo`030000003o
ool0oooo01X0oooo00<0003o0?ooo`3oool09`3oool00`000?l0o`000?ooo`2k0?ooo`006`3oool0
0`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0^`3oool0
01/0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo
0;/0oooo000K0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool09@3oool00`000?l0
o`000?ooo`2l0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02D0oooo
00<0003o0?ooo`3oool0_03oool001/0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0U0?ooo`030000o`3oool0oooo0;`0oooo000K0?ooo`800000703oool00`000?l0oooo0?ooo`0T
0?ooo`030000o`3o0000oooo0;d0oooo000K0?ooo`030000003oool0oooo01/0oooo00<0003o0?oo
o`3oool0903oool00`000?l0oooo0?ooo`2m0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0_@3oool001/0oooo00<000000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3o0000oooo0;h0oooo000K0?ooo`030000003o
ool0oooo01/0oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`2n0?ooo`006`3oool0
0`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0_P3oool0
01/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3o0000oooo
0;l0oooo000K0?ooo`8000007@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0;l0
oooo000K0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo
0?ooo`2o0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0200oooo00<0
003o0?l0003oool0`03oool001/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0P
0?ooo`030000o`3oool0oooo0<00oooo000K0?ooo`030000003oool0oooo01`0oooo00<0003o0?oo
o`3oool0803oool00`000?l0oooo0?ooo`300?ooo`000P3oool2000000@0oooo0P0000030?ooo`D0
00000P3oool2000000D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3o0000oooo0<40oooo00001@3oool000000?ooo`3oool0000000X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0<40oooo00001@3oool000000?ooo`3oool00000
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000007@3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0<40oooo00001@3oool000000?ooo`3oool00000
00X0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`0N0?ooo`030000o`3o0000oooo0<80oooo00001@3oool000000?ooo`3oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01d0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`320?ooo`000P3oool2000000X0
oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01d0
oooo00<0003o0?ooo`3oool0`P3oool001/0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo
0?ooo`0L0?ooo`030000o`3o0000oooo0<<0oooo000K0?ooo`030000003oool0oooo01d0oooo00<0
003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`330?ooo`006`3oool00`000000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0``3oool001/0oooo0P00000N0?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?l0003oool0a03oool001/0oooo00<000000?ooo`3o
ool07@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0<@0oooo000K0?ooo`030000
003oool0oooo01d0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`340?ooo`006`3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?l0003oool0a@3o
ool001/0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo0<D0oooo000K0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`350?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030?l000000?l0oooo01T0
oooo00<0003o0?l0003oool0aP3oool001/0oooo0P00000O0?ooo`030000o`3oool0oooo01P0oooo
00<0003o0?ooo`3oool0aP3oool001/0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`0H0?ooo`030000o`3oool0oooo0<H0oooo000K0?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool05`3oool00`000?l0o`000?ooo`370?ooo`006`3oool00`000000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0a`3oool001/0oooo00<000000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo0<L0oooo000K0?ooo`030000
003oool0oooo01h0oooo00<0003o0?ooo`3oool05P3oool00`000?l0o`000?ooo`380?ooo`006`3o
ool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0b03o
ool001/0oooo0P00000O0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0b03oool0
01/0oooo00<000000?ooo`3oool07P3oool00`3o0000003o0?ooo`0E0?ooo`030000o`3o0000oooo
0<T0oooo000K0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0503oool00`000?l0
oooo0?ooo`390?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool0b@3oool001/0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`0C0?ooo`030000o`3o0000oooo0<X0oooo000K0?ooo`030000003oool0oooo01l0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`3:0?ooo`006`3oool00`000000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0bP3oool001/0oooo0P00000Q0?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?l0003oool0b`3oool001/0oooo00<000000?ooo`3oool0
803oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo0</0oooo000K0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`3;0?ooo`006`3oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0100oooo00<0003o0?l0003oool0c03oool0
01/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0<`0oooo00080?ooo`800000103oool2000000<0oooo100000040?ooo`030000003oool0oooo0200
oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`3<0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3o0000oooo0<d0oooo00070?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0103oool200000280oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`3=0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0<d0
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?l0003oool0cP3oool000P0
oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0cP3oool001/0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3o0000oooo0<l0oooo000K0?ooo`030000003oool0oooo0240oooo00<0
o`000000o`3oool0303oool00`000?l0oooo0?ooo`3?0?ooo`006`3oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?l0003oool0d03oool001/0oooo0P00000S0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0d03oool001/0oooo00<000000?ooo`3o
ool08P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000oooo0=40oooo000K0?ooo`030000
003oool0oooo0280oooo00<0o`000000o`3oool02@3oool00`000?l0o`000?ooo`3A0?ooo`006`3o
ool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0003oool0dP3o
ool001/0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000
oooo0=80oooo000K0?ooo`030000003oool0oooo02<0oooo00<0o`000000o`3oool01P3oool00`00
0?l0o`000?ooo`3C0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3o0000e03oool001/0oooo0P00000U0?ooo`030?l000000?l0oooo00<0oooo
00<0003o0?ooo`3o0000e@3oool001/0oooo00<000000?ooo`3oool09@3oool20000o`80oooo0P00
0?l00`3o0000oooo0?ooo`3D0?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`030?l000000?l0
003o0080003o0P3o003F0?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`@0o`00f03oool001/0
oooo00<000000?ooo`3oool09`3oool20?l00=T0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool0
0?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -0.020676, \
0.0394728, 0.00143703}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Actuator performance in case of the nonlinear model", "Section"],

Cell["\<\
The dynamical operation of the control valve can be described by the c[t] \
function\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[t]\)], "Input"],

Cell[BoxData[
    \(c0 - \(\((\(-h0\) + h[t])\)\ \((c0 - 2\ A\ \@h0\ p\_1 - 2\ A\ \@h0\ \
p\_2)\)\)\/\(2\ h0\) + \(A\ p\_1\ p\_2\ z[t]\)\/\@h0\)], "Output"]
}, Open  ]],

Cell["Introducing numerical values", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[t] /. {A \[Rule] 10. , h0 \[Rule] 9. , Qin0 \[Rule] 9. , 
        c0 \[Rule] 3. , p\_1 \[Rule] 2. , p\_2 \[Rule] 1. }\)], "Input"],

Cell[BoxData[
    \(\(\(3.`\)\(\[InvisibleSpace]\)\) + 
      9.833333333333332`\ \((\(-9.`\) + h[t])\) + 
      6.666666666666666`\ z[t]\)], "Output"]
}, Open  ]],

Cell["The dynamical performance of the control valve is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[% /. {h[t] -> \((h[t] /. numSol)\), 
              z[t] \[Rule] \((z[t] /. numSol)\)}], {t, 0, 10}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1]}, Frame \[Rule] True, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.518763 0.177826 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10363 -18 -4.5 ]
[-0.0125 .10363 0 4.5 ]
[-0.0125 .19254 -6 -4.5 ]
[-0.0125 .19254 0 4.5 ]
[-0.0125 .28145 -18 -4.5 ]
[-0.0125 .28145 0 4.5 ]
[-0.0125 .37037 -6 -4.5 ]
[-0.0125 .37037 0 4.5 ]
[-0.0125 .45928 -18 -4.5 ]
[-0.0125 .45928 0 4.5 ]
[-0.0125 .54819 -6 -4.5 ]
[-0.0125 .54819 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(3)] -0.0125 .01472 1 0 Mshowa
0 .10363 m
.00625 .10363 L
s
[(3.5)] -0.0125 .10363 1 0 Mshowa
0 .19254 m
.00625 .19254 L
s
[(4)] -0.0125 .19254 1 0 Mshowa
0 .28145 m
.00625 .28145 L
s
[(4.5)] -0.0125 .28145 1 0 Mshowa
0 .37037 m
.00625 .37037 L
s
[(5)] -0.0125 .37037 1 0 Mshowa
0 .45928 m
.00625 .45928 L
s
[(5.5)] -0.0125 .45928 1 0 Mshowa
0 .54819 m
.00625 .54819 L
s
[(6)] -0.0125 .54819 1 0 Mshowa
.125 Mabswid
0 .0325 m
.00375 .0325 L
s
0 .05028 m
.00375 .05028 L
s
0 .06806 m
.00375 .06806 L
s
0 .08585 m
.00375 .08585 L
s
0 .12141 m
.00375 .12141 L
s
0 .13919 m
.00375 .13919 L
s
0 .15698 m
.00375 .15698 L
s
0 .17476 m
.00375 .17476 L
s
0 .21032 m
.00375 .21032 L
s
0 .22811 m
.00375 .22811 L
s
0 .24589 m
.00375 .24589 L
s
0 .26367 m
.00375 .26367 L
s
0 .29924 m
.00375 .29924 L
s
0 .31702 m
.00375 .31702 L
s
0 .3348 m
.00375 .3348 L
s
0 .35258 m
.00375 .35258 L
s
0 .38815 m
.00375 .38815 L
s
0 .40593 m
.00375 .40593 L
s
0 .42371 m
.00375 .42371 L
s
0 .4415 m
.00375 .4415 L
s
0 .47706 m
.00375 .47706 L
s
0 .49485 m
.00375 .49485 L
s
0 .51263 m
.00375 .51263 L
s
0 .53041 m
.00375 .53041 L
s
0 .56598 m
.00375 .56598 L
s
0 .58376 m
.00375 .58376 L
s
0 .60154 m
.00375 .60154 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10363 m
1 .10363 L
s
.99375 .19254 m
1 .19254 L
s
.99375 .28145 m
1 .28145 L
s
.99375 .37037 m
1 .37037 L
s
.99375 .45928 m
1 .45928 L
s
.99375 .54819 m
1 .54819 L
s
.125 Mabswid
.99625 .0325 m
1 .0325 L
s
.99625 .05028 m
1 .05028 L
s
.99625 .06806 m
1 .06806 L
s
.99625 .08585 m
1 .08585 L
s
.99625 .12141 m
1 .12141 L
s
.99625 .13919 m
1 .13919 L
s
.99625 .15698 m
1 .15698 L
s
.99625 .17476 m
1 .17476 L
s
.99625 .21032 m
1 .21032 L
s
.99625 .22811 m
1 .22811 L
s
.99625 .24589 m
1 .24589 L
s
.99625 .26367 m
1 .26367 L
s
.99625 .29924 m
1 .29924 L
s
.99625 .31702 m
1 .31702 L
s
.99625 .3348 m
1 .3348 L
s
.99625 .35258 m
1 .35258 L
s
.99625 .38815 m
1 .38815 L
s
.99625 .40593 m
1 .40593 L
s
.99625 .42371 m
1 .42371 L
s
.99625 .4415 m
1 .4415 L
s
.99625 .47706 m
1 .47706 L
s
.99625 .49485 m
1 .49485 L
s
.99625 .51263 m
1 .51263 L
s
.99625 .53041 m
1 .53041 L
s
.99625 .56598 m
1 .56598 L
s
.99625 .58376 m
1 .58376 L
s
.99625 .60154 m
1 .60154 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .03006 L
.12507 .10718 L
.13485 .23079 L
.14415 .32281 L
.15429 .40044 L
.16356 .45491 L
.17354 .49959 L
.18444 .53541 L
.19476 .55973 L
.20411 .57556 L
.2093 .58229 L
.21491 .58819 L
.22017 .59259 L
.22508 .59585 L
.22967 .59825 L
.23459 .60022 L
.23739 .60109 L
.24005 .60177 L
.24241 .60225 L
.24502 .60267 L
.24756 .60298 L
.24896 .6031 L
.25026 .60319 L
.25148 .60325 L
.2526 .60329 L
.25382 .60331 L
.25511 .60332 L
.25643 .6033 L
.25716 .60329 L
.25783 .60326 L
.25913 .60321 L
.26035 .60314 L
.26311 .60293 L
.26609 .60263 L
.27098 .60198 L
.27555 .60121 L
.28596 .59905 L
.30701 .59359 L
.34583 .5827 L
.38711 .57268 L
Mistroke
.42687 .56531 L
.46511 .56015 L
.48647 .55794 L
.50581 .55628 L
.54499 .55371 L
.56428 .55275 L
.58511 .55191 L
.6047 .55125 L
.62617 .55066 L
.66571 .54986 L
.68525 .54957 L
.70618 .54931 L
.72603 .54911 L
.7476 .54893 L
.78749 .54869 L
.80731 .5486 L
.82833 .54852 L
.86613 .54842 L
.88552 .54838 L
.90639 .54834 L
.92607 .54832 L
.94758 .54829 L
.97619 .54827 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool200000300oooo1000000`0?ooo`<00000;P3oool300000300oooo0P00000]0?oo
o`D000000P3oool2000000@0oooo000I0?ooo`040000003oool0oooo000002l0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000002h0oooo00@00000
0?ooo`3oool00000;P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0@3oool001T0oooo00@000000?ooo`3oool00000<03oool00`000000oooo0?ooo`0^0?ooo`D00000
;P3oool010000000oooo0?ooo`00000^0?ooo`040000003oool0oooo000002h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0040oooo000I0?ooo`040000003oool0oooo
00000340oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00000_0?ooo`<00000<03o
ool2000002l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040oooo
000I0?ooo`040000003oool0oooo000002l0oooo00@000000?ooo`3oool00000;`3oool00`000000
oooo0000000`0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000;P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool001X0oooo0P00000a0?oo
o`800000<@3oool200000300oooo0`00000_0?ooo`800000;P3oool2000000@0oooo0P0000040?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`005@3ooooo000000/000000@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool100000040oooo
000>0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`4000000@3oool000d0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`800000103ooolJ0000onP0oooo0P0000010?ooo`00403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0i`3oool10000
0040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`3V0?ooo`4000000@3oool000h0oooo0P0000050?ooo`030000003oool0oooo01d0
oooo00<0003o0?ooo`3oool0iP3oool100000040oooo000E0?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool0iP3oool100000040oooo000E0?ooo`8000007P3oool00`000?l0oooo0?oo
o`3U0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`3V
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`3V0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`3V0?ooo`40
00000@3oool001D0oooo0P00000N0?ooo`030000o`3oool0oooo0>D0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0>H0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0>H0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0>H0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0M0?ooo`030000o`3oool0oooo0>H0oooo0@0000010?ooo`005@3oool2000001h0oooo
00<0003o0?ooo`3oool0i@3oool200000040oooo000E0?ooo`030000003oool0oooo01h0oooo00<0
003o0?ooo`3oool0i@3oool100000040oooo000E0?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool0i@3oool100000040oooo000E0?ooo`030000003oool0oooo01h0oooo00<0003o0?oo
o`3oool0i@3oool100000040oooo000E0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3o
ool0i@3oool100000040oooo000E0?ooo`8000007`3oool00`000?l0oooo0?ooo`3T0?ooo`800000
0@3oool001D0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`3U0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`3U0?ooo`4000000@3oool0
0080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`3U0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0i@3oool1
00000040oooo00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool20000
01l0oooo00<0003o0?ooo`3oool0i03oool200000040oooo00040?ooo`030000003oool0oooo00L0
oooo0P0000050?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0i@3oool100000040
oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo0>D0oooo0@0000010?ooo`000P3oool2000000X0oooo
0`0000040?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0i@3oool100000040oooo
000E0?ooo`8000007`3oool00`000?l0oooo0?ooo`3T0?ooo`8000000@3oool001D0oooo00<00000
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`3U0?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool07P3oool00`000?l0oooo0?ooo`3U0?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`3T0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`3T0?ooo`4000000@3oool001D0oooo0P00000P0?ooo`030000o`3o
ool0oooo0><0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0
oooo0>@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
0>@0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0>@0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0>@0oooo
0@0000010?ooo`005@3oool200000200oooo00<0003o0?ooo`3oool0h`3oool200000040oooo000E
0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0i03oool100000040oooo000E0?oo
o`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0i03oool100000040oooo000E0?ooo`03
0000003oool0oooo0200oooo00<0003o0?ooo`3oool0h`3oool100000040oooo000E0?ooo`030000
003oool0oooo0200oooo00<0003o0?ooo`3oool0h`3oool100000040oooo000E0?ooo`8000008@3o
ool00`000?l0oooo0?ooo`3R0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`3S0?ooo`4000000@3oool000l0oooo0`0000030?ooo`030000003oool0oooo
0200oooo00<0003o0?ooo`3oool0h`3oool100000040oooo000@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`3S0?ooo`4000000@3oool000d0oooo
1@0000030?ooo`8000008@3oool00`000?l0oooo0?ooo`3R0?ooo`8000000@3oool000d0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0><0oooo
0@0000010?ooo`003P3oool00`000000oooo000000040?ooo`030000003oool0oooo0200oooo00<0
003o0?ooo`3oool0h`3oool100000040oooo000?0?ooo`800000103oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo0><0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo0><0oooo0@0000010?ooo`005@3oool200000280oooo00<0003o0?ooo`3o
ool0h@3oool200000040oooo000E0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
hP3oool100000040oooo000E0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0hP3o
ool100000040oooo000E0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0hP3oool1
00000040oooo000E0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0hP3oool10000
0040oooo000E0?ooo`8000008P3oool00`000?l0oooo0?ooo`3Q0?ooo`8000000@3oool001D0oooo
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3R0?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool08@3oool00`000?l0oooo0?ooo`3R0?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`3R0?ooo`4000000@3oool001D0oooo0P00000R0?oo
o`030000o`3oool0oooo0>40oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo0>80oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo0>80oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo0>40oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo0>40oooo0@0000010?ooo`005@3oool2000002<0oooo00<0003o0?ooo`3oool0h03oool20000
0040oooo000E0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0h@3oool100000040
oooo000E0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0h@3oool100000040oooo
00030?ooo`<000000P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool0h@3oool100000040oooo00040?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0>40oooo0@00
00010?ooo`0000<0oooo0000000000000`00000:0?ooo`030000003oool0oooo0080oooo0P00000S
0?ooo`030000o`3oool0oooo0>00oooo0P0000010?ooo`0000D0oooo0000003oool0oooo00000009
0?ooo`8000001@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0>40oooo0@000001
0?ooo`000P3oool00`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`3Q0?ooo`4000000@3oool000<0oooo0P0000090?ooo`<0
0000103oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0>40oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0>40oooo0@0000010?ooo`005@3o
ool2000002@0oooo00<0003o0?ooo`3oool0g`3oool200000040oooo000E0?ooo`030000003oool0
oooo02<0oooo00<0003o0?ooo`3oool0h03oool100000040oooo000E0?ooo`030000003oool0oooo
02<0oooo00<0003o0?ooo`3oool0h03oool100000040oooo000E0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool0h03oool100000040oooo000E0?ooo`800000903oool00`000?l0oooo
0?ooo`3O0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?oo
o`3P0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3P
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3P0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`3P0?ooo`40
00000@3oool001D0oooo0P00000T0?ooo`030000o`3oool0oooo0=l0oooo0P0000010?ooo`005@3o
ool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0=l0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0=l0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0=l0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo0=l0oooo0@0000010?ooo`005@3oool2000002D0oooo
00<0003o0?ooo`3oool0gP3oool200000040oooo000E0?ooo`030000003oool0oooo02@0oooo00<0
003o0?ooo`3oool0g`3oool100000040oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo0=h0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0gP3oool100000040oooo000@0?oo
o`030000003oool0oooo0080oooo0P00000V0?ooo`030000o`3oool0oooo0=d0oooo0P0000010?oo
o`003P3oool2000000D0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`3N0?ooo`40
00000@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000
o`3oool0oooo0=h0oooo0@0000010?ooo`003P3oool3000000@0oooo00<000000?ooo`3oool09@3o
ool00`000?l0oooo0?ooo`3N0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`3N0?ooo`4000000@3oool001D0oooo0P00000W0?ooo`030000o`3oool0oooo
0=`0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0=d0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0=d0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0=d0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0=d0oooo0@000001
0?ooo`005@3oool2000002L0oooo00<0003o0?ooo`3oool0g03oool200000040oooo000E0?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool0g@3oool100000040oooo000E0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0g03oool100000040oooo000E0?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0g03oool100000040oooo000E0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`3oool0g03oool100000040oooo000E0?ooo`800000:03oool00`00
0?l0oooo0?ooo`3K0?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0?ooo`3L0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`3L0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`3L0?ooo`4000000@3oool001D0oooo0P00000X0?ooo`030000o`3oool0oooo0=/0oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0=/0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0=/0oooo0@0000010?ooo`00
0P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo0=/0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`3K0?ooo`40
00000@3oool000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`800000
:@3oool00`000?l0oooo0?ooo`3J0?ooo`8000000@3oool00080oooo0P00000:0?ooo`8000001@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0=X0oooo0@0000010?ooo`000P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`3J0?ooo`4000000@3oool00080oooo0`0000090?ooo`<00000103oool00`00
0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0=X0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0=X0oooo0@0000010?ooo`005@3oool2000002/0oooo
00<0003o0?ooo`3oool0f03oool200000040oooo000E0?ooo`030000003oool0oooo02X0oooo00<0
003o0?ooo`3oool0f@3oool100000040oooo000E0?ooo`030000003oool0oooo02X0oooo00<0003o
0?ooo`3oool0f@3oool100000040oooo000E0?ooo`030000003oool0oooo02X0oooo00<0003o0?oo
o`3oool0f@3oool100000040oooo000E0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3o
ool0f03oool100000040oooo000E0?ooo`800000;03oool00`000?l0oooo0?ooo`3G0?ooo`800000
0@3oool001D0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3H0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`3H0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`3G0?ooo`4000000@3oool001D0
oooo0P00000]0?ooo`030000o`3oool0oooo0=H0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`0/0?ooo`030000o`3oool0oooo0=L0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo0=H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0]
0?ooo`030000o`3oool0oooo0=H0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0]0?oo
o`030000o`3oool0oooo0=H0oooo0@0000010?ooo`005@3oool2000002l0oooo00<0003o0?ooo`3o
ool0e03oool200000040oooo000E0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0
e@3oool100000040oooo000E0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0e@3o
ool100000040oooo000=0?ooo`<000001@3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0
oooo0=@0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo02l0oooo00<0003o0?ooo`3oool0e03oool100000040oooo000=0?ooo`040000003oool0oooo
000000@0oooo0P00000a0?ooo`030000o`3oool0oooo06h0ooooH0000?l40?ooo`8000000@3oool0
00d0oooo0`0000050?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0EP3ooolH0000
ofD0oooo0@0000010?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0340
oooo00<0003o0?ooo`3oool0B03oool=0000ogd0oooo0@0000010?ooo`003P3oool3000000@0oooo
00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`100?ooo`P0003oRP3oool100000040oooo
000E0?ooo`800000<`3oool00`000?l0oooo0?ooo`0g0?ooo`P0003oT@3oool200000040oooo000E
0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0<P3oool50000oiX0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo02d0oooo10000?nO0?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0Y0?ooo`@0
003oX`3oool100000040oooo000E0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0
903oool40000ojL0oooo0@0000010?ooo`005@3oool2000003D0oooo00<0003o0?ooo`3oool08@3o
ool30000ojX0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`80003o7@3oool4
0000ojh0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo
01H0oooo10000?nb0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0>03oool20000oa80
oooo10000?nf0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo
0?ooo`0;0?ooo`@0003o^P3oool100000040oooo000E0?ooo`800000?03oool=0000okd0oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool001D0ooooo`00000;00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.09303, 2.65109, \
0.0395401, 0.0211765}}]
}, Open  ]],

Cell["\<\
It starts with a quick opening , then it is followed  by a slow closing to \
ensure to reach the new steady state.\
\>", "Text"]
}, Closed]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
WindowSize->{678, 561},
WindowMargins->{{220, Automatic}, {Automatic, 84}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1.1"->{
    Cell[2557, 82, 70, 2, 50, "Input",
      CellTags->"1.1"]},
  "6.5"->{
    Cell[3353, 116, 92, 2, 62, "Input",
      CellTags->"6.5"],
    Cell[17336, 350, 125, 3, 50, "Input",
      CellTags->"6.5"],
    Cell[19644, 430, 103, 2, 50, "Input",
      CellTags->"6.5"],
    Cell[19851, 440, 134, 3, 50, "Input",
      CellTags->"6.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.1", 122209, 3266},
  {"6.5", 122284, 3269}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 79, 4, 118, "Title"],
Cell[1836, 57, 152, 6, 112, "Author"],

Cell[CellGroupData[{
Cell[2013, 67, 31, 0, 62, "Section"],
Cell[2047, 69, 507, 11, 67, "Text"],
Cell[2557, 82, 70, 2, 50, "Input",
  CellTags->"1.1"],
Cell[2630, 86, 54, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2721, 92, 59, 0, 42, "Section"],
Cell[2783, 94, 88, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[2896, 100, 188, 4, 74, "Input"],
Cell[3087, 106, 164, 3, 71, "Output"]
}, Open  ]],
Cell[3266, 112, 62, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[3353, 116, 92, 2, 62, "Input",
  CellTags->"6.5"],
Cell[3448, 120, 73, 1, 62, "Output"]
}, Open  ]],
Cell[3536, 124, 85, 2, 29, "Text"],
Cell[3624, 128, 11655, 147, 205, 11559, 144, "GraphicsData", "Metafile", \
"Graphics"],
Cell[15282, 277, 70, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[15377, 281, 118, 2, 50, "Input"],
Cell[15498, 285, 225, 4, 102, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15772, 295, 50, 0, 42, "Section"],
Cell[15825, 297, 244, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[16094, 310, 50, 1, 50, "Input"],
Cell[16147, 313, 1009, 25, 91, "Output"]
}, Open  ]],
Cell[17171, 341, 140, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[17336, 350, 125, 3, 50, "Input",
  CellTags->"6.5"],
Cell[17464, 355, 101, 2, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17602, 362, 132, 3, 51, "Input"],
Cell[17737, 367, 108, 2, 71, "Output"]
}, Open  ]],
Cell[17860, 372, 1759, 54, 27, "Text"],

Cell[CellGroupData[{
Cell[19644, 430, 103, 2, 50, "Input",
  CellTags->"6.5"],
Cell[19750, 434, 64, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19851, 440, 134, 3, 50, "Input",
  CellTags->"6.5"],
Cell[19988, 445, 199, 3, 90, "Output"]
}, Open  ]],
Cell[20202, 451, 345, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[20572, 463, 74, 1, 50, "Input"],
Cell[20649, 466, 141, 2, 90, "Output"]
}, Open  ]],
Cell[20805, 471, 111, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[20941, 478, 62, 1, 50, "Input"],
Cell[21006, 481, 169, 3, 69, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21224, 490, 68, 0, 42, "Section"],
Cell[21295, 492, 189, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[21509, 500, 120, 2, 50, "Input"],
Cell[21632, 504, 219, 3, 67, "Output"]
}, Open  ]],
Cell[21866, 510, 122, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[22013, 517, 238, 5, 70, "Input"],
Cell[22254, 524, 21306, 497, 186, 4016, 279, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[43575, 1024, 122, 3, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[43734, 1032, 67, 0, 42, "Section"],
Cell[43804, 1034, 54, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[43883, 1038, 63, 1, 50, "Input"],
Cell[43949, 1041, 1549, 37, 105, "Output"]
}, Open  ]],
Cell[45513, 1081, 56, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[45594, 1085, 167, 3, 50, "Input"],
Cell[45764, 1090, 156, 2, 73, "Output"]
}, Open  ]],
Cell[45935, 1095, 284, 7, 48, "Text"],
Cell[46222, 1104, 124, 3, 43, "Text"],
Cell[46349, 1109, 42, 0, 29, "Text"],
Cell[46394, 1111, 102, 2, 29, "Text"],
Cell[46499, 1115, 69, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[46593, 1119, 255, 6, 68, "Input"],
Cell[46851, 1127, 376, 8, 112, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47264, 1140, 62, 1, 50, "Input"],
Cell[47329, 1143, 180, 5, 49, "Output"]
}, Open  ]],
Cell[47524, 1151, 41, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[47590, 1155, 167, 3, 50, "Input"],
Cell[47760, 1160, 378, 7, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48175, 1172, 63, 1, 50, "Input"],
Cell[48241, 1175, 181, 5, 49, "Output"]
}, Open  ]],
Cell[48437, 1183, 33, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[48495, 1187, 138, 3, 50, "Input"],
Cell[48636, 1192, 415, 11, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49088, 1208, 210, 4, 70, "Input"],
Cell[49301, 1214, 25591, 684, 186, 5482, 431, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[74907, 1901, 128, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[75060, 1908, 50, 1, 50, "Input"],
Cell[75113, 1911, 22471, 568, 186, 5101, 349, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[97633, 2485, 70, 0, 42, "Section"],
Cell[97706, 2487, 108, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[97839, 2494, 37, 1, 50, "Input"],
Cell[97879, 2497, 156, 2, 73, "Output"]
}, Open  ]],
Cell[98050, 2502, 44, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[98119, 2506, 152, 2, 50, "Input"],
Cell[98274, 2510, 151, 3, 49, "Output"]
}, Open  ]],
Cell[98440, 2516, 65, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[98530, 2520, 260, 5, 70, "Input"],
Cell[98793, 2527, 22621, 714, 186, 6380, 509, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[121429, 3244, 138, 3, 29, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

