(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31318,       1023]*)
(*NotebookOutlinePosition[     32514,       1066]*)
(*  CellTagsIndexPosition[     32393,       1058]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Level control-3
Optimal control\
\>", "Title",
  TextAlignment->Center],

Cell["\<\
B\[EAcute]la Pal\[AAcute]ncz
Budapest Technical University,Hungary
palancz@epito.bme.hu
Budapest,2002\
\>", "Author",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "In this section, we design proportional controller employing built-in \
functions of  linear quadratic regulator and Ricatti equation. In addition \
different solution techniques implemented in ",
  StyleBox["Advanced Numerical Methods",
    FontSlant->"Italic"],
  " are also applied.\nAs we have seen, the nonlinear model of the process is \
"
}], "Text"],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = \(\(-c[t]\)\ \@h[t] + Qin[t]\)\/A\)], "Input"],

Cell[BoxData[
    \(\(\(-c[t]\)\ \@h[t] + Qin[t]\)\/A\)], "Output"]
}, Open  ]],

Cell["The state, input and output variables are", "Text"],

Cell[BoxData[
    \(x = {h[t]}; y = {h[t]}; u = {Qin[t], c[t]}; g = y;\)], "Input"],

Cell[BoxData[
    \(<< ControlSystems`\)], "Input",
  CellTags->"1.1"],

Cell["The linearized form of the model", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControlObjectSS = 
      Linearize[f, g, {{h[t], h0}}, {{Qin[t], Qin0}, {c[t], c0}}]\)], "Input"],

Cell[BoxData[
    \(StateSpace[{{\(-\(c0\/\(2\ A\ \@h0\)\)\)}}, {{1\/A, \(-\(\@h0\/A\)\)}}, \
{{1}}, {{0, 0}}]\)], "Output"]
}, Open  ]],

Cell["In equation form", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControlObjectSS // EquationForm\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[GridBox[{
              {
                RowBox[{\(\[ScriptX]\& . \), "=", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(-\(c0\/\(2\ A\ \@h0\)\)\)}
                        },
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptX]", "+", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(1\/A\), \(-\(\@h0\/A\)\)}
                        },
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptU]"}]},
              {
                RowBox[{"\[ScriptY]", "=", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"1"}
                        },
                      ColumnAlignments->{Decimal},
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptX]", "+", 
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"0", "0"}
                        },
                      ColumnAlignments->{Decimal},
                      AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                  "\[ScriptU]"}]}
              },
            ColumnAlignments->{"="},
            AllowScriptLevelChange->False],
          "TraditionalForm"],
        (EquationForm[ 
          StateSpace[ 
            SlotSequence[ 1]]]&)], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Controllability test", "Section"],

Cell["The controllability matrix", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControllabilityMatrix[ControlObjectSS]\)], "Input"],

Cell[BoxData[
    \({{1\/A, \(-\(\@h0\/A\)\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
In case of controllable system the rank of this matrix must be equal with \
that of the system matrix\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[%] \[Equal] Rank[ControlObjectSS[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Therefore the system controllable. This can be checked by the following \
function, too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Controllable[ControlObjectSS]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Design of linear quadratic regulator", "Section"],

Cell["\<\
Functions supporting  design procedures are not able to handle symbolic \
expressions, therefore we need numerical values\
\>", "Text"],

Cell[BoxData[
    \(\(numericalValues = {A \[Rule] 10. , c0 \[Rule] 3. , Qin0 \[Rule] 9. , 
          h0 \[Rule] 9. };\)\)], "Input"],

Cell[TextData[{
  "Now, the matrices ",
  StyleBox["Q",
    FontSlant->"Italic"],
  " and ",
  StyleBox["R",
    FontSlant->"Italic"],
  "  are choosen in a way, that the gain matrix is nearly the same as it was \
in case of poles assignement design (see ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 1 in ",
  ButtonBox["Level Control1",
    ButtonData:>{"LevelControl1.nb", None},
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[BoxData[
    \(\(q = {{1. }};\)\)], "Input"],

Cell[BoxData[
    \(\(r = {{1000, 0}, {0, 0.0745}};\)\)], "Input"],

Cell["The gains of the input are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LQRegulatorGains[ControlObjectSS /. numericalValues, q, r]\)], "Input",
  CellTags->"10.1"],

Cell[BoxData[
    \({{0.00008693715414658026`}, {\(-3.5008249991911526`\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
Only the second input is controlled (the first one is the disturbace), \
therefore the first gain is eliminated\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[%, 0.001]\)], "Input"],

Cell[BoxData[
    \({{0}, {\(-3.5008249991911526`\)}}\)], "Output"]
}, Open  ]],

Cell["The closed loop system is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StateFeedbackConnect[ControlObjectSS /. numericalValues, %]\)], "Input",\

  CellTags->"10.1"],

Cell[BoxData[
    \(StateSpace[{{\(-1.100247499757346`\)}}, {{0.1`, \(-0.30000000000000004`\
\)}}, {{1.`}}, {{0.`, 0.`}}]\)], "Output"]
}, Open  ]],

Cell["\<\
The disturbance is the unit step function. Then the system response is \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[%, {9.  UnitStep[t - 1], 0}, {t, 0, 10. }, 
        PlotRange \[Rule] {0, 1}, 
        PlotStyle \[Rule] RGBColor[1, 0, 0]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.618034 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 0 m
.06244 0 L
.08255 0 L
.0932 0 L
.10458 0 L
.11009 0 L
.1128 0 L
.11531 0 L
.11758 0 L
.11872 0 L
.11999 .00546 L
.12507 .03396 L
.14415 .12727 L
.16519 .20889 L
.18444 .26804 L
.22321 .35379 L
.2422 .38368 L
.26292 .40963 L
.28424 .43057 L
.30357 .44557 L
.3427 .46738 L
.36194 .47499 L
.38276 .48153 L
.40231 .48638 L
.42376 .49059 L
.46325 .49607 L
.48276 .49798 L
.50368 .49961 L
.52492 .5009 L
.54504 .50187 L
.58337 .50318 L
.60314 .50367 L
.62415 .50407 L
.6619 .5046 L
.68125 .50479 L
.7021 .50495 L
.72175 .50507 L
.74324 .50518 L
.78287 .50531 L
.80248 .50536 L
.82343 .5054 L
.84477 .50543 L
.86493 .50546 L
.90339 .50549 L
.92327 .5055 L
.94431 .50551 L
.97619 .50553 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00BP3oool400000300oooo0`00000/0?ooo`<00000<03oool2000002/0oooo1@0000020?oo
o`8000002P3oool004X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0[0?ooo`04
0000003oool0oooo000002h0oooo00@000000?ooo`3oool00000;03oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01`3oool004/0oooo00<000000?ooo`3oool0;P3oool5
000002`0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`00000/0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`00C03oool00`000000oooo
0?ooo`0]0?ooo`040000003oool0oooo000002d0oooo0`00000`0?ooo`800000;@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool004X0oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0000000^0?ooo`030000003oool0oooo02h0oooo00@000000?oo
o`3oool00000;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3o
ool004/0oooo0P00000a0?ooo`800000;P3oool3000002l0oooo0P00000/0?ooo`800000103oool2
000000X0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo000E0?ooo`H000006P3o003T000000L0oooo000K0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo0>T0oooo000K0?ooo`030000003oool0oooo01H0oooo00<0
o`000?ooo`3oool0j@3oool001/0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`3Y
0?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0>P0oooo000K0?ooo`03
0000003oool0oooo01L0oooo00<0o`000?ooo`3oool0j03oool001/0oooo00<000000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`3X0?ooo`006`3oool2000001P0oooo00<0o`000?ooo`3oool0j03o
ool001/0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3X0?ooo`006`3oool00`00
0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0>P0oooo000K0?ooo`030000003oool0oooo01L0
oooo00<0o`000?ooo`3oool0j03oool001/0oooo00<000000?ooo`3oool0603oool00`3o0000oooo
0?ooo`3W0?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0>L0oooo000K
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0i`3oool001/0oooo00<000000?oo
o`3oool0603oool00`3o0000oooo0?ooo`3W0?ooo`006`3oool2000001T0oooo00<0o`000?ooo`3o
ool0i`3oool001/0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`3V0?ooo`006`3o
ool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0>H0oooo000K0?ooo`030000003oool0
oooo01T0oooo00<0o`000?ooo`3oool0iP3oool001/0oooo00<000000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`3V0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0>D0
oooo000K0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0i@3oool001/0oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3U0?ooo`006`3oool2000001/0oooo00<0o`00
0?ooo`3oool0i@3oool001/0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3U0?oo
o`006`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0>@0oooo000K0?ooo`030000
003oool0oooo01/0oooo00<0o`000?ooo`3oool0i03oool001/0oooo00<000000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`3T0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0
oooo0>@0oooo00080?ooo`800000103oool2000000<0oooo100000040?ooo`030000003oool0oooo
01/0oooo00<0o`000?ooo`3oool0i03oool000L0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0h`3oool000L0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`<00000703oool00`3o
0000oooo0?ooo`3S0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3S0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool0
0`3o0000oooo0?ooo`3S0?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo
01d0oooo00<0o`000?ooo`3oool0hP3oool001/0oooo00<000000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`3R0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0>80oooo
000K0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0hP3oool001/0oooo00<00000
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`3Q0?ooo`006`3oool2000001l0oooo00<0o`000?oo
o`3oool0h@3oool001/0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`3Q0?ooo`00
6`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0>00oooo000K0?ooo`030000003o
ool0oooo01l0oooo00<0o`000?ooo`3oool0h03oool001/0oooo00<000000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`3P0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
0>00oooo000K0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0g`3oool001/0oooo
00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3O0?ooo`006`3oool200000240oooo00<0
o`000?ooo`3oool0g`3oool001/0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`3N
0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0=h0oooo000K0?ooo`03
0000003oool0oooo0240oooo00<0o`000?ooo`3oool0gP3oool001/0oooo00<000000?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`3N0?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030?l0003o
ool0oooo0=d0oooo000K0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0g@3oool0
01/0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo0?ooo`3M0?ooo`006`3oool2000002@0
oooo00<0o`000?ooo`3oool0g03oool001/0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo
0?ooo`3L0?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0=`0oooo000K
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0f`3oool001/0oooo00<000000?oo
o`3oool0903oool00`3o0000oooo0?ooo`3K0?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`03
0?l0003oool0oooo0=/0oooo00080?ooo`800000103oool2000000D0oooo0`0000030?ooo`030000
003oool0oooo02D0oooo00<0o`000?ooo`3oool0fP3oool000L0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0
fP3oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0`00000U0?ooo`030?l0
003oool0oooo0=X0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0=T0oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo0=T0oooo00080?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`3I0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo0=P0oooo000K0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0f03oool0
01/0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`3H0?ooo`006`3oool00`000000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo0=L0oooo000K0?ooo`800000:@3oool00`3o0000oooo
0?ooo`3G0?ooo`006`3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0=H0oooo000K
0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0eP3oool001/0oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`3E0?ooo`006`3oool00`000000oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo0=D0oooo000K0?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool0
e@3oool001/0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`3D0?ooo`006`3oool0
0`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0=@0oooo000K0?ooo`800000;@3oool00`3o
0000oooo0?ooo`3C0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0=<0
oooo000K0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0dP3oool001/0oooo00<0
00000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`3B0?ooo`006`3oool00`000000oooo0?ooo`0^
0?ooo`030?l0003oool0oooo0=40oooo000K0?ooo`030000003oool0oooo02h0oooo00<0o`000?oo
o`3oool0d@3oool001/0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`3A0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo0=00oooo000K0?ooo`800000<03o
ool00`3o0000oooo0?ooo`3@0?ooo`006`3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0
oooo0<l0oooo000K0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool0c`3oool001/0
oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`3>0?ooo`006`3oool00`000000oooo
0?ooo`0a0?ooo`030?l0003oool0oooo0<h0oooo000K0?ooo`030000003oool0oooo0380oooo00<0
o`000?ooo`3oool0c@3oool000P0oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<00000
0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`3=0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?oo
o`3<0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
0`00000d0?ooo`030?l0003oool0oooo0</0oooo00070?ooo`040000003oool0oooo000000P0oooo
0`0000050?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0bP3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo
00<0o`000?ooo`3oool0bP3oool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?oo
o`0f0?ooo`030?l0003oool0oooo0<T0oooo000K0?ooo`030000003oool0oooo03L0oooo00<0o`00
0?ooo`3oool0b03oool001/0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`380?oo
o`006`3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0<L0oooo000K0?ooo`030000
003oool0oooo03T0oooo00<0o`000?ooo`3oool0aP3oool001/0oooo0P00000k0?ooo`030?l0003o
ool0oooo0<D0oooo000K0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0a@3oool0
01/0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`340?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`030?l0003oool0oooo0<<0oooo000K0?ooo`030000003oool0oooo03d0oooo
00<0o`000?ooo`3oool0`P3oool001/0oooo00<000000?ooo`3oool0?P3oool20?l00<80oooo000K
0?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0_`3oool001/0oooo00<000000?oo
o`3oool0@@3oool00`3o0000oooo0?ooo`2n0?ooo`006`3oool2000004<0oooo00<0o`000?ooo`3o
ool0_@3oool001/0oooo00<000000?ooo`3oool0@`3oool20?l00;d0oooo000K0?ooo`030000003o
ool0oooo04D0oooo00<0o`000?ooo`3oool0^P3oool001/0oooo00<000000?ooo`3oool0AP3oool0
0`3o0000oooo0?ooo`2i0?ooo`006`3oool00`000000oooo0?ooo`170?ooo`80o`00^@3oool001/0
oooo00<000000?ooo`3oool0B@3oool20?l00;L0oooo000K0?ooo`030000003oool0oooo04/0oooo
00<0o`000?ooo`3oool0]03oool001/0oooo00<000000?ooo`3oool0C03oool20?l00;@0oooo000K
0?ooo`800000C`3oool20?l00;80oooo000K0?ooo`030000003oool0oooo0500oooo0P3o002`0?oo
o`006`3oool00`000000oooo0?ooo`1B0?ooo`80o`00[P3oool001/0oooo00<000000?ooo`3oool0
E03oool30?l00:/0oooo000K0?ooo`030000003oool0oooo05L0oooo0P3o002Y0?ooo`006`3oool0
0`000000oooo0?ooo`1I0?ooo`@0o`00Y@3oool000P0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0G@3oool50?l00:00oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1R0?ooo`P0o`00V03oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`<00000JP3o
ool80?l00900oooo00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003o
ool0oooo0780oooo2P3o00260?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0O03ooolR0?l006@0oooo00080?ooo`8000002P3o
ool2000000D0oooo00<000000?ooo`3oool0WP3ooomG0?l000d0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00
003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000
003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool3
0?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool0
0`3oool300000?l0oooo0`3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000D0?ooo`800000o`3oool;0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.11819, -0.0764114, \
0.0405086, 0.00624232}}]
}, Open  ]],

Cell[TextData[{
  "We get the same system performace as in ",
  ButtonBox["Level Control1.nb",
    ButtonData:>{"LevelControl1.nb", None},
    ButtonStyle->"Hyperlink"],
  " using pole assignment design method.\nOne may employ different solution \
methods like"
}], "Text"],

Cell[BoxData[
    \(<< NumericalControlMethods`\)], "Input",
  CellTags->"3.2.1"],

Cell[TextData[{
  StyleBox["Schur",
    FontSlant->"Italic"],
  " - ",
  StyleBox["decomposition",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LQRegulatorGains[ControlObjectSS /. numericalValues, q, r, 
      SolveMethod \[Rule] SchurDecomposition]\)], "Input",
  CellTags->"10.1"],

Cell[BoxData[
    \({{0.00008693715414658026`}, {\(-3.5008249991911526`\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "or ",
  StyleBox["matrix Sign function",
    FontSlant->"Italic"],
  " method"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LQRegulatorGains[ControlObjectSS /. numericalValues, q, r, 
      SolveMethod \[Rule] MatrixSign]\)], "Input",
  CellTags->"10.1"],

Cell[BoxData[
    \({{0.00008693715414658026`}, {\(-3.5008249991911518`\)}}\)], "Output"]
}, Open  ]],

Cell["leading to the same result.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving Ricatti equation with CSP2 functions", "Section"],

Cell[TextData[{
  "To employ Ricatti eqution, one needs the ",
  StyleBox["A",
    FontSlant->"Italic"],
  " and ",
  StyleBox["B",
    FontSlant->"Italic"],
  " matrices"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControlObjectSS // TraditionalForm\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(c0\/\(2\ A\ \@h0\)\)\), \(1\/A\), \
\(-\(\@h0\/A\)\)},
                    {"1", "0", "0"}
                    },
                  RowLines->{True, False},
                  ColumnLines->{True, False},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalS]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (StateSpace[ 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = %[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({{\(-\(c0\/\(2\ A\ \@h0\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b = %%[\([2]\)]\)], "Input"],

Cell[BoxData[
    \({{1\/A, \(-\(\@h0\/A\)\)}}\)], "Output"]
}, Open  ]],

Cell["here the numerical form is necessary", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aa = a /. numericalValues\)], "Input"],

Cell[BoxData[
    \({{\(-0.05`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bb = b /. numericalValues\)], "Input"],

Cell[BoxData[
    \({{0.1`, \(-0.30000000000000004`\)}}\)], "Output"]
}, Open  ]],

Cell["Then different methods can be applied, like", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiccatiSolve[aa, bb, q, r, 
      SolveMethod \[Rule] SchurDecomposition]\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658026`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiccatiSolve[aa, bb, q, r, 
      SolveMethod \[Rule] GeneralizedSchurDecomposition]\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658026`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiccatiSolve[aa, bb, q, r, SolveMethod \[Rule] MatrixSign]\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658025`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(w = 
      RiccatiSolve[aa, bb, q, r, SolveMethod \[Rule] Newton, 
        InitialGuess \[Rule] {{1. }}]\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658024`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiccatiSolve[aa, bb, q, r, 
      SolveMethod \[Rule] GeneralizedEigendecomposition]\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658026`}}\)], "Output"]
}, Open  ]],

Cell["These methods work, and give the same result. ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving Ricatti equation with Solve (symbolic solution)", "Section"],

Cell[TextData[{
  "The  functions of CSP2 solving Ricatti equation have been worked, but they \
work in numerical form. Now, let us solve Ricatti equation in symbolic way \
directly employing standard built-in function ",
  StyleBox["Solve",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(w =. \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(req = 
      Transpose[a] . {{w}} + {{w}} . a - {{w}} . b . Inverse[r] . 
            Transpose[b] . {{w}} + q // Simplify\)], "Input"],

Cell[BoxData[
    \({{\(\(1.`\)\(\[InvisibleSpace]\)\) - \(c0\ w\)\/\(A\ \@h0\) + \
\(\((\(-0.001`\) + 0.`\ \@h0 - 13.422818791946309`\ h0)\)\ w\^2\)\/A\^2}}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[req \[Equal] 0, w]\)], "Input"],

Cell[BoxData[
    \({{w \[Rule] \(0.5`\ A\^2\ \((\(-\(\(1.`\ c0\)\/\(A\ \@h0\)\)\) - \(1.`\ \
\@\(1.`\ c0\^2 + 0.004`\ h0 + 53.691275167785236`\ h0\^2\)\)\/\(A\ \
\@h0\))\)\)\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + 13.422818791946309`\ \
h0\)}, {w \[Rule] \(0.5`\ A\^2\ \((\(-\(\(1.`\ c0\)\/\(A\ \@h0\)\)\) + \(1.`\ \
\@\(1.`\ c0\^2 + 0.004`\ h0 + 53.691275167785236`\ h0\^2\)\)\/\(A\ \
\@h0\))\)\)\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + 13.422818791946309`\ \
h0\)}}\)], "Output"]
}, Open  ]],

Cell["The first solution is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w1 = {{w /. %[\([1]\)]}}\)], "Input"],

Cell[BoxData[
    \({{\(0.5`\ A\^2\ \((\(-\(\(1.`\ c0\)\/\(A\ \@h0\)\)\) - \(1.`\ \@\(1.`\ \
c0\^2 + 0.004`\ h0 + 53.691275167785236`\ h0\^2\)\)\/\(A\ \
\@h0\))\)\)\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + 13.422818791946309`\ \
h0\)}}\)], "Output"]
}, Open  ]],

Cell["and the second one", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w2 = {{w /. %%[\([2]\)]}}\)], "Input"],

Cell[BoxData[
    \({{\(0.5`\ A\^2\ \((\(-\(\(1.`\ c0\)\/\(A\ \@h0\)\)\) + \(1.`\ \@\(1.`\ \
c0\^2 + 0.004`\ h0 + 53.691275167785236`\ h0\^2\)\)\/\(A\ \
\@h0\))\)\)\/\(\(\(0.001`\)\(\[InvisibleSpace]\)\) + 13.422818791946309`\ \
h0\)}}\)], "Output"]
}, Open  ]],

Cell["The numerical values are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w1n = w1 /. numericalValues\)], "Input"],

Cell[BoxData[
    \({{\(-0.9521486340332029`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(w2n = w2 /. numericalValues\)], "Input"],

Cell[BoxData[
    \({{0.8693715414658025`}}\)], "Output"]
}, Open  ]],

Cell["\<\
The second value is the same, which was computed by the CSP2 methods, which \
is the correct value.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Computing gain matrix from the Ricatti solution", "Section"],

Cell["\<\
If the solution of the Ricatti equation is known, the gain matrix can be \
computed as\
\>", "Text"],

Cell[BoxData[
    \(K = \ \(R\^\(-1\)\) \(B\^T\) W\)], "Text",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[r] . Transpose[bb] . w2n\)], "Input"],

Cell[BoxData[
    \({{0.00008693715414658026`}, {\(-3.5008249991911513`\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the same gain matrix provided by the ",
  StyleBox["LQRegulatorGains",
    FontSlant->"Italic"],
  " function."
}], "Text"]
}, Closed]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
WindowSize->{729, 824},
WindowMargins->{{171, Automatic}, {30, Automatic}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1.1"->{
    Cell[2808, 96, 70, 2, 50, "Input",
      CellTags->"1.1"]},
  "10.1"->{
    Cell[6672, 245, 111, 2, 50, "Input",
      CellTags->"10.1"],
    Cell[7248, 271, 114, 3, 50, "Input",
      CellTags->"10.1"],
    Cell[24131, 724, 158, 3, 70, "Input",
      CellTags->"10.1"],
    Cell[24530, 742, 150, 3, 50, "Input",
      CellTags->"10.1"]},
  "3.2.1"->{
    Cell[23887, 710, 81, 2, 50, "Input",
      CellTags->"3.2.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.1", 31944, 1039},
  {"10.1", 32020, 1042},
  {"3.2.1", 32300, 1051}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 81, 4, 118, "Title"],
Cell[1838, 57, 152, 6, 112, "Author"],

Cell[CellGroupData[{
Cell[2015, 67, 31, 0, 62, "Section"],
Cell[2049, 69, 376, 8, 79, "Text"],
Cell[2428, 79, 54, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[2507, 84, 70, 1, 68, "Input"],
Cell[2580, 87, 67, 1, 67, "Output"]
}, Open  ]],
Cell[2662, 91, 57, 0, 29, "Text"],
Cell[2722, 93, 83, 1, 50, "Input"],
Cell[2808, 96, 70, 2, 50, "Input",
  CellTags->"1.1"],
Cell[2881, 100, 48, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[2954, 104, 117, 2, 50, "Input"],
Cell[3074, 108, 124, 2, 71, "Output"]
}, Open  ]],
Cell[3213, 113, 32, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[3270, 117, 64, 1, 50, "Input"],
Cell[3337, 120, 1483, 36, 105, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4869, 162, 39, 0, 42, "Section"],
Cell[4911, 164, 42, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4978, 168, 71, 1, 50, "Input"],
Cell[5052, 171, 60, 1, 67, "Output"]
}, Open  ]],
Cell[5127, 175, 125, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[5277, 182, 80, 1, 50, "Input"],
Cell[5360, 185, 38, 1, 49, "Output"]
}, Open  ]],
Cell[5413, 189, 112, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[5550, 196, 62, 1, 50, "Input"],
Cell[5615, 199, 38, 1, 49, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5702, 206, 55, 0, 42, "Section"],
Cell[5760, 208, 145, 3, 29, "Text"],
Cell[5908, 213, 133, 2, 50, "Input"],
Cell[6044, 217, 437, 16, 48, "Text"],
Cell[6484, 235, 49, 1, 50, "Input"],
Cell[6536, 238, 66, 1, 50, "Input"],
Cell[6605, 241, 42, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[6672, 245, 111, 2, 50, "Input",
  CellTags->"10.1"],
Cell[6786, 249, 89, 1, 49, "Output"]
}, Open  ]],
Cell[6890, 253, 135, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[7050, 260, 47, 1, 50, "Input"],
Cell[7100, 263, 67, 1, 49, "Output"]
}, Open  ]],
Cell[7182, 267, 41, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[7248, 271, 114, 3, 50, "Input",
  CellTags->"10.1"],
Cell[7365, 276, 135, 2, 49, "Output"]
}, Open  ]],
Cell[7515, 281, 95, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[7635, 287, 176, 3, 70, "Input"],
Cell[7814, 292, 15782, 406, 186, 3469, 249, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[23611, 701, 273, 7, 60, "Text"],
Cell[23887, 710, 81, 2, 50, "Input",
  CellTags->"3.2.1"],
Cell[23971, 714, 135, 6, 29, "Text"],

Cell[CellGroupData[{
Cell[24131, 724, 158, 3, 70, "Input",
  CellTags->"10.1"],
Cell[24292, 729, 89, 1, 49, "Output"]
}, Open  ]],
Cell[24396, 733, 109, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[24530, 742, 150, 3, 50, "Input",
  CellTags->"10.1"],
Cell[24683, 747, 89, 1, 49, "Output"]
}, Open  ]],
Cell[24787, 751, 43, 0, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[24867, 756, 63, 0, 42, "Section"],
Cell[24933, 758, 183, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[25141, 770, 67, 1, 50, "Input"],
Cell[25211, 773, 898, 25, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26146, 803, 47, 1, 50, "Input"],
Cell[26196, 806, 65, 1, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26298, 812, 48, 1, 50, "Input"],
Cell[26349, 815, 60, 1, 67, "Output"]
}, Open  ]],
Cell[26424, 819, 52, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[26501, 823, 58, 1, 50, "Input"],
Cell[26562, 826, 48, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26647, 832, 58, 1, 50, "Input"],
Cell[26708, 835, 69, 1, 49, "Output"]
}, Open  ]],
Cell[26792, 839, 92, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[26909, 844, 106, 2, 50, "Input"],
Cell[27018, 848, 57, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27112, 854, 117, 2, 50, "Input"],
Cell[27232, 858, 57, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27326, 864, 91, 1, 50, "Input"],
Cell[27420, 867, 57, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27514, 873, 137, 3, 50, "Input"],
Cell[27654, 878, 57, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27748, 884, 117, 2, 50, "Input"],
Cell[27868, 888, 57, 1, 49, "Output"]
}, Open  ]],
Cell[27940, 892, 62, 0, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28039, 897, 74, 0, 42, "Section"],
Cell[28116, 899, 285, 7, 48, "Text"],
Cell[28404, 908, 38, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[28467, 913, 155, 3, 50, "Input"],
Cell[28625, 918, 173, 3, 73, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28835, 926, 57, 1, 50, "Input"],
Cell[28895, 929, 484, 7, 155, "Output"]
}, Open  ]],
Cell[29394, 939, 37, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[29456, 943, 57, 1, 50, "Input"],
Cell[29516, 946, 249, 4, 88, "Output"]
}, Open  ]],
Cell[29780, 953, 34, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[29839, 957, 58, 1, 50, "Input"],
Cell[29900, 960, 249, 4, 88, "Output"]
}, Open  ]],
Cell[30164, 967, 40, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[30229, 971, 60, 1, 50, "Input"],
Cell[30292, 974, 62, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30391, 980, 60, 1, 50, "Input"],
Cell[30454, 983, 57, 1, 49, "Output"]
}, Open  ]],
Cell[30526, 987, 123, 3, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[30686, 995, 66, 0, 42, "Section"],
Cell[30755, 997, 110, 3, 29, "Text"],
Cell[30868, 1002, 87, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[30980, 1008, 65, 1, 50, "Input"],
Cell[31048, 1011, 89, 1, 49, "Output"]
}, Open  ]],
Cell[31152, 1015, 150, 5, 29, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

